// Copyright 2026 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.26.0
// 	protoc        v4.24.4
// source: google/chromeos/moblab/v1beta1/resources.proto

package moblab

import (
	reflect "reflect"
	sync "sync"

	_ "google.golang.org/genproto/googleapis/api/annotations"
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	durationpb "google.golang.org/protobuf/types/known/durationpb"
	timestamppb "google.golang.org/protobuf/types/known/timestamppb"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

// The build status types.
type Build_BuildStatus int32

const (
	// No build status is specified.
	Build_BUILD_STATUS_UNSPECIFIED Build_BuildStatus = 0
	// Complete Status: The build passed.
	Build_PASS Build_BuildStatus = 1
	// Complete Status: The build failed.
	Build_FAIL Build_BuildStatus = 2
	// Intermediate Status: The build is still running.
	Build_RUNNING Build_BuildStatus = 3
	// Complete Status: The build was aborted.
	Build_ABORTED Build_BuildStatus = 4
)

// Enum value maps for Build_BuildStatus.
var (
	Build_BuildStatus_name = map[int32]string{
		0: "BUILD_STATUS_UNSPECIFIED",
		1: "PASS",
		2: "FAIL",
		3: "RUNNING",
		4: "ABORTED",
	}
	Build_BuildStatus_value = map[string]int32{
		"BUILD_STATUS_UNSPECIFIED": 0,
		"PASS":                     1,
		"FAIL":                     2,
		"RUNNING":                  3,
		"ABORTED":                  4,
	}
)

func (x Build_BuildStatus) Enum() *Build_BuildStatus {
	p := new(Build_BuildStatus)
	*p = x
	return p
}

func (x Build_BuildStatus) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (Build_BuildStatus) Descriptor() protoreflect.EnumDescriptor {
	return file_google_chromeos_moblab_v1beta1_resources_proto_enumTypes[0].Descriptor()
}

func (Build_BuildStatus) Type() protoreflect.EnumType {
	return &file_google_chromeos_moblab_v1beta1_resources_proto_enumTypes[0]
}

func (x Build_BuildStatus) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use Build_BuildStatus.Descriptor instead.
func (Build_BuildStatus) EnumDescriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{3, 0}
}

// The build types.
type Build_BuildType int32

const (
	// Invalid build type.
	Build_BUILD_TYPE_UNSPECIFIED Build_BuildType = 0
	// The release build.
	Build_RELEASE Build_BuildType = 1
	// The firmware build.
	Build_FIRMWARE Build_BuildType = 2
)

// Enum value maps for Build_BuildType.
var (
	Build_BuildType_name = map[int32]string{
		0: "BUILD_TYPE_UNSPECIFIED",
		1: "RELEASE",
		2: "FIRMWARE",
	}
	Build_BuildType_value = map[string]int32{
		"BUILD_TYPE_UNSPECIFIED": 0,
		"RELEASE":                1,
		"FIRMWARE":               2,
	}
)

func (x Build_BuildType) Enum() *Build_BuildType {
	p := new(Build_BuildType)
	*p = x
	return p
}

func (x Build_BuildType) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (Build_BuildType) Descriptor() protoreflect.EnumDescriptor {
	return file_google_chromeos_moblab_v1beta1_resources_proto_enumTypes[1].Descriptor()
}

func (Build_BuildType) Type() protoreflect.EnumType {
	return &file_google_chromeos_moblab_v1beta1_resources_proto_enumTypes[1]
}

func (x Build_BuildType) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use Build_BuildType.Descriptor instead.
func (Build_BuildType) EnumDescriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{3, 1}
}

// The CloudBuild states.
type CloudBuild_State int32

const (
	// No cloud build state is specified.
	CloudBuild_STATE_UNSPECIFIED CloudBuild_State = 0
	// The cloud build is queued.
	CloudBuild_QUEUED CloudBuild_State = 1
	// The cloud build is pending.
	CloudBuild_PENDING CloudBuild_State = 2
	// The cloud build is working.
	CloudBuild_WORKING CloudBuild_State = 3
	// The cloud build is successful.
	CloudBuild_SUCCEEDED CloudBuild_State = 4
	// The cloud build is failed.
	CloudBuild_FAILED CloudBuild_State = 5
	// The cloud build is failed due to internal error.
	CloudBuild_INTERNAL_ERROR CloudBuild_State = 6
	// The cloud build is failed due to timeout.
	CloudBuild_TIMEOUT CloudBuild_State = 7
	// The cloud build is cancelled.
	CloudBuild_CANCELLED CloudBuild_State = 8
	// The cloud build is expired.
	CloudBuild_EXPIRED CloudBuild_State = 9
)

// Enum value maps for CloudBuild_State.
var (
	CloudBuild_State_name = map[int32]string{
		0: "STATE_UNSPECIFIED",
		1: "QUEUED",
		2: "PENDING",
		3: "WORKING",
		4: "SUCCEEDED",
		5: "FAILED",
		6: "INTERNAL_ERROR",
		7: "TIMEOUT",
		8: "CANCELLED",
		9: "EXPIRED",
	}
	CloudBuild_State_value = map[string]int32{
		"STATE_UNSPECIFIED": 0,
		"QUEUED":            1,
		"PENDING":           2,
		"WORKING":           3,
		"SUCCEEDED":         4,
		"FAILED":            5,
		"INTERNAL_ERROR":    6,
		"TIMEOUT":           7,
		"CANCELLED":         8,
		"EXPIRED":           9,
	}
)

func (x CloudBuild_State) Enum() *CloudBuild_State {
	p := new(CloudBuild_State)
	*p = x
	return p
}

func (x CloudBuild_State) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (CloudBuild_State) Descriptor() protoreflect.EnumDescriptor {
	return file_google_chromeos_moblab_v1beta1_resources_proto_enumTypes[2].Descriptor()
}

func (CloudBuild_State) Type() protoreflect.EnumType {
	return &file_google_chromeos_moblab_v1beta1_resources_proto_enumTypes[2]
}

func (x CloudBuild_State) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use CloudBuild_State.Descriptor instead.
func (CloudBuild_State) EnumDescriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{5, 0}
}

// The possible states of a test effort.
type TestEffort_State int32

const (
	// No test effort state is specified.
	TestEffort_STATE_UNSPECIFIED TestEffort_State = 0
	// The test effort is created.
	TestEffort_CREATED TestEffort_State = 1
	// The test effort has incomplete results.
	TestEffort_INCOMPLETE TestEffort_State = 2
	// The test effort has failed.
	TestEffort_FAILED TestEffort_State = 3
	// The test effort has unreported results.
	TestEffort_UNREPORTED TestEffort_State = 4
	// The test effort is not applicable.
	TestEffort_NOT_APPLICABLE TestEffort_State = 5
	// The test effort has passed.
	TestEffort_SUCCEEDED TestEffort_State = 6
	// The test effort is requested to be cancelled.
	TestEffort_CANCEL_REQUESTED TestEffort_State = 7
	// The test effort is cancelled.
	TestEffort_CANCELLED TestEffort_State = 8
	// The cancelling the test effort failed.
	TestEffort_CANCEL_FAILED TestEffort_State = 9
)

// Enum value maps for TestEffort_State.
var (
	TestEffort_State_name = map[int32]string{
		0: "STATE_UNSPECIFIED",
		1: "CREATED",
		2: "INCOMPLETE",
		3: "FAILED",
		4: "UNREPORTED",
		5: "NOT_APPLICABLE",
		6: "SUCCEEDED",
		7: "CANCEL_REQUESTED",
		8: "CANCELLED",
		9: "CANCEL_FAILED",
	}
	TestEffort_State_value = map[string]int32{
		"STATE_UNSPECIFIED": 0,
		"CREATED":           1,
		"INCOMPLETE":        2,
		"FAILED":            3,
		"UNREPORTED":        4,
		"NOT_APPLICABLE":    5,
		"SUCCEEDED":         6,
		"CANCEL_REQUESTED":  7,
		"CANCELLED":         8,
		"CANCEL_FAILED":     9,
	}
)

func (x TestEffort_State) Enum() *TestEffort_State {
	p := new(TestEffort_State)
	*p = x
	return p
}

func (x TestEffort_State) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (TestEffort_State) Descriptor() protoreflect.EnumDescriptor {
	return file_google_chromeos_moblab_v1beta1_resources_proto_enumTypes[3].Descriptor()
}

func (TestEffort_State) Type() protoreflect.EnumType {
	return &file_google_chromeos_moblab_v1beta1_resources_proto_enumTypes[3]
}

func (x TestEffort_State) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use TestEffort_State.Descriptor instead.
func (TestEffort_State) EnumDescriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{9, 0}
}

// The firmware type.
type TestEffort_FirmwareType int32

const (
	// No firmware type is specified.
	TestEffort_FIRMWARE_TYPE_UNSPECIFIED TestEffort_FirmwareType = 0
	// The read only firmware type.
	TestEffort_READ_ONLY TestEffort_FirmwareType = 1
	// The read write firmware type.
	TestEffort_READ_WRITE TestEffort_FirmwareType = 2
)

// Enum value maps for TestEffort_FirmwareType.
var (
	TestEffort_FirmwareType_name = map[int32]string{
		0: "FIRMWARE_TYPE_UNSPECIFIED",
		1: "READ_ONLY",
		2: "READ_WRITE",
	}
	TestEffort_FirmwareType_value = map[string]int32{
		"FIRMWARE_TYPE_UNSPECIFIED": 0,
		"READ_ONLY":                 1,
		"READ_WRITE":                2,
	}
)

func (x TestEffort_FirmwareType) Enum() *TestEffort_FirmwareType {
	p := new(TestEffort_FirmwareType)
	*p = x
	return p
}

func (x TestEffort_FirmwareType) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (TestEffort_FirmwareType) Descriptor() protoreflect.EnumDescriptor {
	return file_google_chromeos_moblab_v1beta1_resources_proto_enumTypes[4].Descriptor()
}

func (TestEffort_FirmwareType) Type() protoreflect.EnumType {
	return &file_google_chromeos_moblab_v1beta1_resources_proto_enumTypes[4]
}

func (x TestEffort_FirmwareType) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use TestEffort_FirmwareType.Descriptor instead.
func (TestEffort_FirmwareType) EnumDescriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{9, 1}
}

// The category of pool to schedule tests against.
type TestEffort_Pool_PoolType int32

const (
	// Not used. Exists to distinguish between an unset value and DEFAULT.
	TestEffort_Pool_POOL_TYPE_UNSPECIFIED TestEffort_Pool_PoolType = 0
	// Pools used when scheduling tests without any special exceptions
	TestEffort_Pool_DEFAULT_POOL TestEffort_Pool_PoolType = 1
	// Pools to use when scheduling FAFT PD tests.
	TestEffort_Pool_FAFT_PD TestEffort_Pool_PoolType = 2
	// Pools to schedule tests with extremely long runtimes (3+ hours)
	TestEffort_Pool_EXTENDED_DURATION TestEffort_Pool_PoolType = 3
)

// Enum value maps for TestEffort_Pool_PoolType.
var (
	TestEffort_Pool_PoolType_name = map[int32]string{
		0: "POOL_TYPE_UNSPECIFIED",
		1: "DEFAULT_POOL",
		2: "FAFT_PD",
		3: "EXTENDED_DURATION",
	}
	TestEffort_Pool_PoolType_value = map[string]int32{
		"POOL_TYPE_UNSPECIFIED": 0,
		"DEFAULT_POOL":          1,
		"FAFT_PD":               2,
		"EXTENDED_DURATION":     3,
	}
)

func (x TestEffort_Pool_PoolType) Enum() *TestEffort_Pool_PoolType {
	p := new(TestEffort_Pool_PoolType)
	*p = x
	return p
}

func (x TestEffort_Pool_PoolType) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (TestEffort_Pool_PoolType) Descriptor() protoreflect.EnumDescriptor {
	return file_google_chromeos_moblab_v1beta1_resources_proto_enumTypes[5].Descriptor()
}

func (TestEffort_Pool_PoolType) Type() protoreflect.EnumType {
	return &file_google_chromeos_moblab_v1beta1_resources_proto_enumTypes[5]
}

func (x TestEffort_Pool_PoolType) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use TestEffort_Pool_PoolType.Descriptor instead.
func (TestEffort_Pool_PoolType) EnumDescriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{9, 1, 0}
}

// Resource that represents a build target.
// -- NEXT_TAG: 2 --
type BuildTarget struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// The resource name of the build target.
	// Format: buildTargets/{build_target}
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
}

func (x *BuildTarget) Reset() {
	*x = BuildTarget{}
	if protoimpl.UnsafeEnabled {
		mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *BuildTarget) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BuildTarget) ProtoMessage() {}

func (x *BuildTarget) ProtoReflect() protoreflect.Message {
	mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BuildTarget.ProtoReflect.Descriptor instead.
func (*BuildTarget) Descriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{0}
}

func (x *BuildTarget) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

// Resource that represents a model. Each model belongs to a build target. For
// non-unified build, the model name is the same as its build target name.
// -- NEXT_TAG: 2 --
type Model struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// The resource name of the model.
	// Format: buildTargets/{build_target}/models/{model}
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
}

func (x *Model) Reset() {
	*x = Model{}
	if protoimpl.UnsafeEnabled {
		mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[1]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *Model) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Model) ProtoMessage() {}

func (x *Model) ProtoReflect() protoreflect.Message {
	mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[1]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Model.ProtoReflect.Descriptor instead.
func (*Model) Descriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{1}
}

func (x *Model) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

// Resource that represents a chrome OS milestone.
// -- NEXT_TAG: 2 --
type Milestone struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// The resource name of the milestone.
	// Format: milestones/{milestone}
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
}

func (x *Milestone) Reset() {
	*x = Milestone{}
	if protoimpl.UnsafeEnabled {
		mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[2]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *Milestone) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Milestone) ProtoMessage() {}

func (x *Milestone) ProtoReflect() protoreflect.Message {
	mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[2]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Milestone.ProtoReflect.Descriptor instead.
func (*Milestone) Descriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{2}
}

func (x *Milestone) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

// Resource that represents a build for the given build target, model, milestone
// and build version.
// -- NEXT_TAG: 9 --
type Build struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// The resource name of the build.
	// Format: buildTargets/{build_target}/models/{model}/builds/{build}
	// Example: buildTargets/octopus/models/bobba/builds/1234.0.0
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// The milestone that owns the build.
	// Format: milestones/{milestone}
	Milestone string `protobuf:"bytes,2,opt,name=milestone,proto3" json:"milestone,omitempty"`
	// The build version of the build, e.g. 1234.0.0.
	BuildVersion string `protobuf:"bytes,3,opt,name=build_version,json=buildVersion,proto3" json:"build_version,omitempty"`
	// The status of the build.
	Status Build_BuildStatus `protobuf:"varint,4,opt,name=status,proto3,enum=google.chromeos.moblab.v1beta1.Build_BuildStatus" json:"status,omitempty"`
	// The type of the build.
	Type Build_BuildType `protobuf:"varint,5,opt,name=type,proto3,enum=google.chromeos.moblab.v1beta1.Build_BuildType" json:"type,omitempty"`
	// The branch of the build.
	Branch string `protobuf:"bytes,6,opt,name=branch,proto3" json:"branch,omitempty"`
	// The firmware version of the software that is flashed to the chip on the
	// Chrome OS device.
	RwFirmwareVersion string `protobuf:"bytes,7,opt,name=rw_firmware_version,json=rwFirmwareVersion,proto3" json:"rw_firmware_version,omitempty"`
	// The labels of the build.
	Labels []string `protobuf:"bytes,8,rep,name=labels,proto3" json:"labels,omitempty"`
}

func (x *Build) Reset() {
	*x = Build{}
	if protoimpl.UnsafeEnabled {
		mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[3]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *Build) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Build) ProtoMessage() {}

func (x *Build) ProtoReflect() protoreflect.Message {
	mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[3]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Build.ProtoReflect.Descriptor instead.
func (*Build) Descriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{3}
}

func (x *Build) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *Build) GetMilestone() string {
	if x != nil {
		return x.Milestone
	}
	return ""
}

func (x *Build) GetBuildVersion() string {
	if x != nil {
		return x.BuildVersion
	}
	return ""
}

func (x *Build) GetStatus() Build_BuildStatus {
	if x != nil {
		return x.Status
	}
	return Build_BUILD_STATUS_UNSPECIFIED
}

func (x *Build) GetType() Build_BuildType {
	if x != nil {
		return x.Type
	}
	return Build_BUILD_TYPE_UNSPECIFIED
}

func (x *Build) GetBranch() string {
	if x != nil {
		return x.Branch
	}
	return ""
}

func (x *Build) GetRwFirmwareVersion() string {
	if x != nil {
		return x.RwFirmwareVersion
	}
	return ""
}

func (x *Build) GetLabels() []string {
	if x != nil {
		return x.Labels
	}
	return nil
}

// Resource that represents a build artifact stored in Google Cloud Storage for
// the given build target, model, build version and bucket.
// -- NEXT_TAG: 6 --
type BuildArtifact struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// The resource name of the build artifact.
	// Format:
	// buildTargets/{build_target}/models/{model}/builds/{build}/artifacts/{artifact}
	// Example:
	// buildTargets/octopus/models/bobba/builds/1234.0.0/artifacts/chromeos-moblab-peng-staging
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// The build metadata of the build artifact.
	Build string `protobuf:"bytes,2,opt,name=build,proto3" json:"build,omitempty"`
	// The bucket that stores the build artifact.
	Bucket string `protobuf:"bytes,3,opt,name=bucket,proto3" json:"bucket,omitempty"`
	// The path of the build artifact in the bucket.
	Path string `protobuf:"bytes,4,opt,name=path,proto3" json:"path,omitempty"`
	// The number of objects in the build artifact folder. The object number can
	// be used to calculated the stage progress by comparing the source build
	// artifact with the destination build artifact.
	ObjectCount uint32 `protobuf:"varint,5,opt,name=object_count,json=objectCount,proto3" json:"object_count,omitempty"`
}

func (x *BuildArtifact) Reset() {
	*x = BuildArtifact{}
	if protoimpl.UnsafeEnabled {
		mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[4]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *BuildArtifact) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BuildArtifact) ProtoMessage() {}

func (x *BuildArtifact) ProtoReflect() protoreflect.Message {
	mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[4]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BuildArtifact.ProtoReflect.Descriptor instead.
func (*BuildArtifact) Descriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{4}
}

func (x *BuildArtifact) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *BuildArtifact) GetBuild() string {
	if x != nil {
		return x.Build
	}
	return ""
}

func (x *BuildArtifact) GetBucket() string {
	if x != nil {
		return x.Bucket
	}
	return ""
}

func (x *BuildArtifact) GetPath() string {
	if x != nil {
		return x.Path
	}
	return ""
}

func (x *BuildArtifact) GetObjectCount() uint32 {
	if x != nil {
		return x.ObjectCount
	}
	return 0
}

// Cloud build message for staging a build artifact.
// This message is partially copied from the source proto
// devtools/cloudbuild/v1/cloudbuild.proto
// -- NEXT_TAG: 6 --
type CloudBuild struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// Output only. Unique identifier of the cloud build.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// Output only. State of the cloud build.
	Status CloudBuild_State `protobuf:"varint,2,opt,name=status,proto3,enum=google.chromeos.moblab.v1beta1.CloudBuild_State" json:"status,omitempty"`
	// Output only. Time at which the request to create the build was received.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. Time at which execution of the build was started.
	StartTime *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=start_time,json=startTime,proto3" json:"start_time,omitempty"`
	// Output only. Time at which execution of the build was finished.
	//
	// The difference between finish_time and start_time is the duration of the
	// build's execution.
	FinishTime *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=finish_time,json=finishTime,proto3" json:"finish_time,omitempty"`
}

func (x *CloudBuild) Reset() {
	*x = CloudBuild{}
	if protoimpl.UnsafeEnabled {
		mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[5]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *CloudBuild) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CloudBuild) ProtoMessage() {}

func (x *CloudBuild) ProtoReflect() protoreflect.Message {
	mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[5]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CloudBuild.ProtoReflect.Descriptor instead.
func (*CloudBuild) Descriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{5}
}

func (x *CloudBuild) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

func (x *CloudBuild) GetStatus() CloudBuild_State {
	if x != nil {
		return x.Status
	}
	return CloudBuild_STATE_UNSPECIFIED
}

func (x *CloudBuild) GetCreateTime() *timestamppb.Timestamp {
	if x != nil {
		return x.CreateTime
	}
	return nil
}

func (x *CloudBuild) GetStartTime() *timestamppb.Timestamp {
	if x != nil {
		return x.StartTime
	}
	return nil
}

func (x *CloudBuild) GetFinishTime() *timestamppb.Timestamp {
	if x != nil {
		return x.FinishTime
	}
	return nil
}

// A session to run on-demand tests.
// -- NEXT_TAG: 7 --
type Session struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// Identifier. The resource name of the session.
	// Format: sessions/{session}
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Optional. The ID of the Satlab that the request comes from.
	SatlabId string `protobuf:"bytes,2,opt,name=satlab_id,json=satlabId,proto3" json:"satlab_id,omitempty"`
	// Required. Input only. The dimensions of the device(s) to run tests on.
	Dimensions map[string]string `protobuf:"bytes,3,rep,name=dimensions,proto3" json:"dimensions,omitempty" protobuf_key:"bytes,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"`
	// Optional. Input only. The timeout settings for the test run.
	Timeout *Timeout `protobuf:"bytes,4,opt,name=timeout,proto3" json:"timeout,omitempty"`
	// Optional. Input only. The number of shards to use for the test run.
	ShardCount int32 `protobuf:"varint,5,opt,name=shard_count,json=shardCount,proto3" json:"shard_count,omitempty"`
	// The test to run.
	//
	// Types that are assignable to Test:
	//
	//	*Session_TradefedTest
	Test isSession_Test `protobuf_oneof:"test"`
}

func (x *Session) Reset() {
	*x = Session{}
	if protoimpl.UnsafeEnabled {
		mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[6]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *Session) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Session) ProtoMessage() {}

func (x *Session) ProtoReflect() protoreflect.Message {
	mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[6]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Session.ProtoReflect.Descriptor instead.
func (*Session) Descriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{6}
}

func (x *Session) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *Session) GetSatlabId() string {
	if x != nil {
		return x.SatlabId
	}
	return ""
}

func (x *Session) GetDimensions() map[string]string {
	if x != nil {
		return x.Dimensions
	}
	return nil
}

func (x *Session) GetTimeout() *Timeout {
	if x != nil {
		return x.Timeout
	}
	return nil
}

func (x *Session) GetShardCount() int32 {
	if x != nil {
		return x.ShardCount
	}
	return 0
}

func (m *Session) GetTest() isSession_Test {
	if m != nil {
		return m.Test
	}
	return nil
}

func (x *Session) GetTradefedTest() *TradefedTest {
	if x, ok := x.GetTest().(*Session_TradefedTest); ok {
		return x.TradefedTest
	}
	return nil
}

type isSession_Test interface {
	isSession_Test()
}

type Session_TradefedTest struct {
	// Input only. A Tradefed-based test.
	TradefedTest *TradefedTest `protobuf:"bytes,6,opt,name=tradefed_test,json=tradefedTest,proto3,oneof"`
}

func (*Session_TradefedTest) isSession_Test() {}

// Timeout settings for the test run.
// -- NEXT_TAG: 4 --
type Timeout struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// Optional. Max execution time of a job.
	JobTimeout *durationpb.Duration `protobuf:"bytes,1,opt,name=job_timeout,json=jobTimeout,proto3" json:"job_timeout,omitempty"`
	// Optional. Max execution time of a single test.
	TestTimeout *durationpb.Duration `protobuf:"bytes,2,opt,name=test_timeout,json=testTimeout,proto3" json:"test_timeout,omitempty"`
	// Optional. Timeout for starting the job and waiting for allocating the first
	// device.
	StartTimeout *durationpb.Duration `protobuf:"bytes,3,opt,name=start_timeout,json=startTimeout,proto3" json:"start_timeout,omitempty"`
}

func (x *Timeout) Reset() {
	*x = Timeout{}
	if protoimpl.UnsafeEnabled {
		mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[7]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *Timeout) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Timeout) ProtoMessage() {}

func (x *Timeout) ProtoReflect() protoreflect.Message {
	mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[7]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Timeout.ProtoReflect.Descriptor instead.
func (*Timeout) Descriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{7}
}

func (x *Timeout) GetJobTimeout() *durationpb.Duration {
	if x != nil {
		return x.JobTimeout
	}
	return nil
}

func (x *Timeout) GetTestTimeout() *durationpb.Duration {
	if x != nil {
		return x.TestTimeout
	}
	return nil
}

func (x *Timeout) GetStartTimeout() *durationpb.Duration {
	if x != nil {
		return x.StartTimeout
	}
	return nil
}

// Configuration for a Tradefed-based test.
// -- NEXT_TAG: 2 --
type TradefedTest struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// Required. The command to run the Tradefed test.
	Command string `protobuf:"bytes,1,opt,name=command,proto3" json:"command,omitempty"`
}

func (x *TradefedTest) Reset() {
	*x = TradefedTest{}
	if protoimpl.UnsafeEnabled {
		mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[8]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *TradefedTest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TradefedTest) ProtoMessage() {}

func (x *TradefedTest) ProtoReflect() protoreflect.Message {
	mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[8]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TradefedTest.ProtoReflect.Descriptor instead.
func (*TradefedTest) Descriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{8}
}

func (x *TradefedTest) GetCommand() string {
	if x != nil {
		return x.Command
	}
	return ""
}

// Summary information for an entire test effort
type TestEffort struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// Identifier. The resource name of the test effort.
	// Format: testEfforts/{test_effort}
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Output only. The ID of the test effort.
	TestEffortId string `protobuf:"bytes,2,opt,name=test_effort_id,json=testEffortId,proto3" json:"test_effort_id,omitempty"`
	// Optional. The satlab ID that the test effort comes from.
	SatlabId string `protobuf:"bytes,3,opt,name=satlab_id,json=satlabId,proto3" json:"satlab_id,omitempty"`
	// The test target of the test effort.
	//
	// Types that are assignable to TestTarget:
	//
	//	*TestEffort_BoardModel_
	TestTarget isTestEffort_TestTarget `protobuf_oneof:"test_target"`
	// Required. The pools of the test effort.
	Pools []*TestEffort_Pool `protobuf:"bytes,5,rep,name=pools,proto3" json:"pools,omitempty"`
	// Required. Test plan reference.
	TestPlan string `protobuf:"bytes,6,opt,name=test_plan,json=testPlan,proto3" json:"test_plan,omitempty"`
	// Specifies the Operating System build targets to test against.
	//
	// Types that are assignable to Os:
	//
	//	*TestEffort_Android
	Os isTestEffort_Os `protobuf_oneof:"os"`
	// Output only. Overall result of the test effort.
	State TestEffort_State `protobuf:"varint,8,opt,name=state,proto3,enum=google.chromeos.moblab.v1beta1.TestEffort_State" json:"state,omitempty"`
	// Output only. The time when the test effort was created.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,9,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. Testhaus link.
	TesthausUrl string `protobuf:"bytes,10,opt,name=testhaus_url,json=testhausUrl,proto3" json:"testhaus_url,omitempty"`
	// Optional. The firmware configuration of the test effort.
	FirmwareConfigs []*TestEffort_FirmwareConfig `protobuf:"bytes,11,rep,name=firmware_configs,json=firmwareConfigs,proto3" json:"firmware_configs,omitempty"`
}

func (x *TestEffort) Reset() {
	*x = TestEffort{}
	if protoimpl.UnsafeEnabled {
		mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[9]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *TestEffort) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TestEffort) ProtoMessage() {}

func (x *TestEffort) ProtoReflect() protoreflect.Message {
	mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[9]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TestEffort.ProtoReflect.Descriptor instead.
func (*TestEffort) Descriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{9}
}

func (x *TestEffort) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *TestEffort) GetTestEffortId() string {
	if x != nil {
		return x.TestEffortId
	}
	return ""
}

func (x *TestEffort) GetSatlabId() string {
	if x != nil {
		return x.SatlabId
	}
	return ""
}

func (m *TestEffort) GetTestTarget() isTestEffort_TestTarget {
	if m != nil {
		return m.TestTarget
	}
	return nil
}

func (x *TestEffort) GetBoardModel() *TestEffort_BoardModel {
	if x, ok := x.GetTestTarget().(*TestEffort_BoardModel_); ok {
		return x.BoardModel
	}
	return nil
}

func (x *TestEffort) GetPools() []*TestEffort_Pool {
	if x != nil {
		return x.Pools
	}
	return nil
}

func (x *TestEffort) GetTestPlan() string {
	if x != nil {
		return x.TestPlan
	}
	return ""
}

func (m *TestEffort) GetOs() isTestEffort_Os {
	if m != nil {
		return m.Os
	}
	return nil
}

func (x *TestEffort) GetAndroid() *TestEffort_AndroidBuildTarget {
	if x, ok := x.GetOs().(*TestEffort_Android); ok {
		return x.Android
	}
	return nil
}

func (x *TestEffort) GetState() TestEffort_State {
	if x != nil {
		return x.State
	}
	return TestEffort_STATE_UNSPECIFIED
}

func (x *TestEffort) GetCreateTime() *timestamppb.Timestamp {
	if x != nil {
		return x.CreateTime
	}
	return nil
}

func (x *TestEffort) GetTesthausUrl() string {
	if x != nil {
		return x.TesthausUrl
	}
	return ""
}

func (x *TestEffort) GetFirmwareConfigs() []*TestEffort_FirmwareConfig {
	if x != nil {
		return x.FirmwareConfigs
	}
	return nil
}

type isTestEffort_TestTarget interface {
	isTestEffort_TestTarget()
}

type TestEffort_BoardModel_ struct {
	// The board and model of the test effort.
	BoardModel *TestEffort_BoardModel `protobuf:"bytes,4,opt,name=board_model,json=boardModel,proto3,oneof"`
}

func (*TestEffort_BoardModel_) isTestEffort_TestTarget() {}

type isTestEffort_Os interface {
	isTestEffort_Os()
}

type TestEffort_Android struct {
	// Test against an Android build.
	Android *TestEffort_AndroidBuildTarget `protobuf:"bytes,7,opt,name=android,proto3,oneof"`
}

func (*TestEffort_Android) isTestEffort_Os() {}

// The board and model of the test effort.
type TestEffort_BoardModel struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// Required. The board name.
	Board string `protobuf:"bytes,1,opt,name=board,proto3" json:"board,omitempty"`
	// Required. The model name.
	Model string `protobuf:"bytes,2,opt,name=model,proto3" json:"model,omitempty"`
}

func (x *TestEffort_BoardModel) Reset() {
	*x = TestEffort_BoardModel{}
	if protoimpl.UnsafeEnabled {
		mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[11]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *TestEffort_BoardModel) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TestEffort_BoardModel) ProtoMessage() {}

func (x *TestEffort_BoardModel) ProtoReflect() protoreflect.Message {
	mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[11]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TestEffort_BoardModel.ProtoReflect.Descriptor instead.
func (*TestEffort_BoardModel) Descriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{9, 0}
}

func (x *TestEffort_BoardModel) GetBoard() string {
	if x != nil {
		return x.Board
	}
	return ""
}

func (x *TestEffort_BoardModel) GetModel() string {
	if x != nil {
		return x.Model
	}
	return ""
}

// The pool of the test effort.
type TestEffort_Pool struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// Required. The label of the pool.
	Label string `protobuf:"bytes,1,opt,name=label,proto3" json:"label,omitempty"`
	// Required. The category of pool to schedule tests against.
	Type TestEffort_Pool_PoolType `protobuf:"varint,2,opt,name=type,proto3,enum=google.chromeos.moblab.v1beta1.TestEffort_Pool_PoolType" json:"type,omitempty"`
}

func (x *TestEffort_Pool) Reset() {
	*x = TestEffort_Pool{}
	if protoimpl.UnsafeEnabled {
		mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[12]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *TestEffort_Pool) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TestEffort_Pool) ProtoMessage() {}

func (x *TestEffort_Pool) ProtoReflect() protoreflect.Message {
	mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[12]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TestEffort_Pool.ProtoReflect.Descriptor instead.
func (*TestEffort_Pool) Descriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{9, 1}
}

func (x *TestEffort_Pool) GetLabel() string {
	if x != nil {
		return x.Label
	}
	return ""
}

func (x *TestEffort_Pool) GetType() TestEffort_Pool_PoolType {
	if x != nil {
		return x.Type
	}
	return TestEffort_Pool_POOL_TYPE_UNSPECIFIED
}

// Represents the Android build target.
type TestEffort_AndroidBuildTarget struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// Required. Represents the name of a configured branch in the Android Build
	// system
	Branch string `protobuf:"bytes,1,opt,name=branch,proto3" json:"branch,omitempty"`
	// Required. Specifies the release configuration of the build target.
	ReleaseConfig string `protobuf:"bytes,2,opt,name=release_config,json=releaseConfig,proto3" json:"release_config,omitempty"`
	// Required. Specifies the build variant for the target.
	BuildVariant string `protobuf:"bytes,3,opt,name=build_variant,json=buildVariant,proto3" json:"build_variant,omitempty"`
	// Required. The build ID of the test effort.
	BuildId string `protobuf:"bytes,4,opt,name=build_id,json=buildId,proto3" json:"build_id,omitempty"`
	// Optional. Product name of the build target.
	Product string `protobuf:"bytes,5,opt,name=product,proto3" json:"product,omitempty"`
}

func (x *TestEffort_AndroidBuildTarget) Reset() {
	*x = TestEffort_AndroidBuildTarget{}
	if protoimpl.UnsafeEnabled {
		mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[13]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *TestEffort_AndroidBuildTarget) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TestEffort_AndroidBuildTarget) ProtoMessage() {}

func (x *TestEffort_AndroidBuildTarget) ProtoReflect() protoreflect.Message {
	mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[13]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TestEffort_AndroidBuildTarget.ProtoReflect.Descriptor instead.
func (*TestEffort_AndroidBuildTarget) Descriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{9, 2}
}

func (x *TestEffort_AndroidBuildTarget) GetBranch() string {
	if x != nil {
		return x.Branch
	}
	return ""
}

func (x *TestEffort_AndroidBuildTarget) GetReleaseConfig() string {
	if x != nil {
		return x.ReleaseConfig
	}
	return ""
}

func (x *TestEffort_AndroidBuildTarget) GetBuildVariant() string {
	if x != nil {
		return x.BuildVariant
	}
	return ""
}

func (x *TestEffort_AndroidBuildTarget) GetBuildId() string {
	if x != nil {
		return x.BuildId
	}
	return ""
}

func (x *TestEffort_AndroidBuildTarget) GetProduct() string {
	if x != nil {
		return x.Product
	}
	return ""
}

// The version of the firmware test effort.
type TestEffort_FirmwareTestEffortVersion struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// Required. The major version of the firmware test effort.
	MajorVersion int32 `protobuf:"varint,1,opt,name=major_version,json=majorVersion,proto3" json:"major_version,omitempty"`
	// Required. The minor version of the firmware test effort.
	MinorVersion int32 `protobuf:"varint,2,opt,name=minor_version,json=minorVersion,proto3" json:"minor_version,omitempty"`
	// Required. The patch number of the firmware test effort.
	PatchNumber int32 `protobuf:"varint,3,opt,name=patch_number,json=patchNumber,proto3" json:"patch_number,omitempty"`
	// Optional. The URI of the firmware.
	Uri string `protobuf:"bytes,4,opt,name=uri,proto3" json:"uri,omitempty"`
}

func (x *TestEffort_FirmwareTestEffortVersion) Reset() {
	*x = TestEffort_FirmwareTestEffortVersion{}
	if protoimpl.UnsafeEnabled {
		mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[14]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *TestEffort_FirmwareTestEffortVersion) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TestEffort_FirmwareTestEffortVersion) ProtoMessage() {}

func (x *TestEffort_FirmwareTestEffortVersion) ProtoReflect() protoreflect.Message {
	mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[14]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TestEffort_FirmwareTestEffortVersion.ProtoReflect.Descriptor instead.
func (*TestEffort_FirmwareTestEffortVersion) Descriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{9, 3}
}

func (x *TestEffort_FirmwareTestEffortVersion) GetMajorVersion() int32 {
	if x != nil {
		return x.MajorVersion
	}
	return 0
}

func (x *TestEffort_FirmwareTestEffortVersion) GetMinorVersion() int32 {
	if x != nil {
		return x.MinorVersion
	}
	return 0
}

func (x *TestEffort_FirmwareTestEffortVersion) GetPatchNumber() int32 {
	if x != nil {
		return x.PatchNumber
	}
	return 0
}

func (x *TestEffort_FirmwareTestEffortVersion) GetUri() string {
	if x != nil {
		return x.Uri
	}
	return ""
}

// The version of the GSC test effort.
type TestEffort_GscTestEffortVersion struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// Required. The major version of the GSC test effort
	MajorVersion int32 `protobuf:"varint,1,opt,name=major_version,json=majorVersion,proto3" json:"major_version,omitempty"`
	// Required. The minor version of the GSC test effort.
	MinorVersion int32 `protobuf:"varint,2,opt,name=minor_version,json=minorVersion,proto3" json:"minor_version,omitempty"`
	// Required. The epoch of the GSC test effort.
	Generation int32 `protobuf:"varint,3,opt,name=generation,proto3" json:"generation,omitempty"`
	// Optional. The URI of the GSC.
	Uri string `protobuf:"bytes,4,opt,name=uri,proto3" json:"uri,omitempty"`
}

func (x *TestEffort_GscTestEffortVersion) Reset() {
	*x = TestEffort_GscTestEffortVersion{}
	if protoimpl.UnsafeEnabled {
		mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[15]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *TestEffort_GscTestEffortVersion) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TestEffort_GscTestEffortVersion) ProtoMessage() {}

func (x *TestEffort_GscTestEffortVersion) ProtoReflect() protoreflect.Message {
	mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[15]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TestEffort_GscTestEffortVersion.ProtoReflect.Descriptor instead.
func (*TestEffort_GscTestEffortVersion) Descriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{9, 4}
}

func (x *TestEffort_GscTestEffortVersion) GetMajorVersion() int32 {
	if x != nil {
		return x.MajorVersion
	}
	return 0
}

func (x *TestEffort_GscTestEffortVersion) GetMinorVersion() int32 {
	if x != nil {
		return x.MinorVersion
	}
	return 0
}

func (x *TestEffort_GscTestEffortVersion) GetGeneration() int32 {
	if x != nil {
		return x.Generation
	}
	return 0
}

func (x *TestEffort_GscTestEffortVersion) GetUri() string {
	if x != nil {
		return x.Uri
	}
	return ""
}

// The target of the firmware.
type TestEffort_FirmwareTarget struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// The firmware content.
	//
	// Types that are assignable to Fw:
	//
	//	*TestEffort_FirmwareTarget_Ec
	//	*TestEffort_FirmwareTarget_Ap
	//	*TestEffort_FirmwareTarget_Gsc
	//	*TestEffort_FirmwareTarget_Fpmcu
	Fw isTestEffort_FirmwareTarget_Fw `protobuf_oneof:"fw"`
}

func (x *TestEffort_FirmwareTarget) Reset() {
	*x = TestEffort_FirmwareTarget{}
	if protoimpl.UnsafeEnabled {
		mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[16]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *TestEffort_FirmwareTarget) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TestEffort_FirmwareTarget) ProtoMessage() {}

func (x *TestEffort_FirmwareTarget) ProtoReflect() protoreflect.Message {
	mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[16]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TestEffort_FirmwareTarget.ProtoReflect.Descriptor instead.
func (*TestEffort_FirmwareTarget) Descriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{9, 5}
}

func (m *TestEffort_FirmwareTarget) GetFw() isTestEffort_FirmwareTarget_Fw {
	if m != nil {
		return m.Fw
	}
	return nil
}

func (x *TestEffort_FirmwareTarget) GetEc() *TestEffort_FirmwareTestEffortVersion {
	if x, ok := x.GetFw().(*TestEffort_FirmwareTarget_Ec); ok {
		return x.Ec
	}
	return nil
}

func (x *TestEffort_FirmwareTarget) GetAp() *TestEffort_FirmwareTestEffortVersion {
	if x, ok := x.GetFw().(*TestEffort_FirmwareTarget_Ap); ok {
		return x.Ap
	}
	return nil
}

func (x *TestEffort_FirmwareTarget) GetGsc() *TestEffort_GscTestEffortVersion {
	if x, ok := x.GetFw().(*TestEffort_FirmwareTarget_Gsc); ok {
		return x.Gsc
	}
	return nil
}

func (x *TestEffort_FirmwareTarget) GetFpmcu() *TestEffort_FirmwareTestEffortVersion {
	if x, ok := x.GetFw().(*TestEffort_FirmwareTarget_Fpmcu); ok {
		return x.Fpmcu
	}
	return nil
}

type isTestEffort_FirmwareTarget_Fw interface {
	isTestEffort_FirmwareTarget_Fw()
}

type TestEffort_FirmwareTarget_Ec struct {
	// The EC firmware version.
	Ec *TestEffort_FirmwareTestEffortVersion `protobuf:"bytes,1,opt,name=ec,proto3,oneof"`
}

type TestEffort_FirmwareTarget_Ap struct {
	// The AP firmware version.
	Ap *TestEffort_FirmwareTestEffortVersion `protobuf:"bytes,2,opt,name=ap,proto3,oneof"`
}

type TestEffort_FirmwareTarget_Gsc struct {
	// The GSC firmware version.
	Gsc *TestEffort_GscTestEffortVersion `protobuf:"bytes,3,opt,name=gsc,proto3,oneof"`
}

type TestEffort_FirmwareTarget_Fpmcu struct {
	// The FPMCU firmware version.
	Fpmcu *TestEffort_FirmwareTestEffortVersion `protobuf:"bytes,4,opt,name=fpmcu,proto3,oneof"`
}

func (*TestEffort_FirmwareTarget_Ec) isTestEffort_FirmwareTarget_Fw() {}

func (*TestEffort_FirmwareTarget_Ap) isTestEffort_FirmwareTarget_Fw() {}

func (*TestEffort_FirmwareTarget_Gsc) isTestEffort_FirmwareTarget_Fw() {}

func (*TestEffort_FirmwareTarget_Fpmcu) isTestEffort_FirmwareTarget_Fw() {}

// The configuration of the firmware.
type TestEffort_FirmwareConfig struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// Required. The firmware target.
	FirmwareTarget *TestEffort_FirmwareTarget `protobuf:"bytes,1,opt,name=firmware_target,json=firmwareTarget,proto3" json:"firmware_target,omitempty"`
	// Required. The firmware types.
	FirmwareTypes []TestEffort_FirmwareType `protobuf:"varint,2,rep,packed,name=firmware_types,json=firmwareTypes,proto3,enum=google.chromeos.moblab.v1beta1.TestEffort_FirmwareType" json:"firmware_types,omitempty"`
}

func (x *TestEffort_FirmwareConfig) Reset() {
	*x = TestEffort_FirmwareConfig{}
	if protoimpl.UnsafeEnabled {
		mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[17]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *TestEffort_FirmwareConfig) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TestEffort_FirmwareConfig) ProtoMessage() {}

func (x *TestEffort_FirmwareConfig) ProtoReflect() protoreflect.Message {
	mi := &file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[17]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TestEffort_FirmwareConfig.ProtoReflect.Descriptor instead.
func (*TestEffort_FirmwareConfig) Descriptor() ([]byte, []int) {
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP(), []int{9, 6}
}

func (x *TestEffort_FirmwareConfig) GetFirmwareTarget() *TestEffort_FirmwareTarget {
	if x != nil {
		return x.FirmwareTarget
	}
	return nil
}

func (x *TestEffort_FirmwareConfig) GetFirmwareTypes() []TestEffort_FirmwareType {
	if x != nil {
		return x.FirmwareTypes
	}
	return nil
}

var File_google_chromeos_moblab_v1beta1_resources_proto protoreflect.FileDescriptor

var file_google_chromeos_moblab_v1beta1_resources_proto_rawDesc = []byte{
	0x0a, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2f, 0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65, 0x6f,
	0x73, 0x2f, 0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2f, 0x76, 0x31, 0x62, 0x65, 0x74, 0x61, 0x31,
	0x2f, 0x72, 0x65, 0x73, 0x6f, 0x75, 0x72, 0x63, 0x65, 0x73, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f,
	0x12, 0x1e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65, 0x6f,
	0x73, 0x2e, 0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e, 0x76, 0x31, 0x62, 0x65, 0x74, 0x61, 0x31,
	0x1a, 0x1f, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2f, 0x61, 0x70, 0x69, 0x2f, 0x66, 0x69, 0x65,
	0x6c, 0x64, 0x5f, 0x62, 0x65, 0x68, 0x61, 0x76, 0x69, 0x6f, 0x72, 0x2e, 0x70, 0x72, 0x6f, 0x74,
	0x6f, 0x1a, 0x19, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2f, 0x61, 0x70, 0x69, 0x2f, 0x72, 0x65,
	0x73, 0x6f, 0x75, 0x72, 0x63, 0x65, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x1a, 0x1e, 0x67, 0x6f,
	0x6f, 0x67, 0x6c, 0x65, 0x2f, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x62, 0x75, 0x66, 0x2f, 0x64, 0x75,
	0x72, 0x61, 0x74, 0x69, 0x6f, 0x6e, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x1a, 0x1f, 0x67, 0x6f,
	0x6f, 0x67, 0x6c, 0x65, 0x2f, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x62, 0x75, 0x66, 0x2f, 0x74, 0x69,
	0x6d, 0x65, 0x73, 0x74, 0x61, 0x6d, 0x70, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x6e, 0x0a,
	0x0b, 0x42, 0x75, 0x69, 0x6c, 0x64, 0x54, 0x61, 0x72, 0x67, 0x65, 0x74, 0x12, 0x12, 0x0a, 0x04,
	0x6e, 0x61, 0x6d, 0x65, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x52, 0x04, 0x6e, 0x61, 0x6d, 0x65,
	0x3a, 0x4b, 0xea, 0x41, 0x48, 0x0a, 0x29, 0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65, 0x6f, 0x73, 0x6d,
	0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x61, 0x70, 0x69, 0x73,
	0x2e, 0x63, 0x6f, 0x6d, 0x2f, 0x42, 0x75, 0x69, 0x6c, 0x64, 0x54, 0x61, 0x72, 0x67, 0x65, 0x74,
	0x12, 0x1b, 0x62, 0x75, 0x69, 0x6c, 0x64, 0x54, 0x61, 0x72, 0x67, 0x65, 0x74, 0x73, 0x2f, 0x7b,
	0x62, 0x75, 0x69, 0x6c, 0x64, 0x5f, 0x74, 0x61, 0x72, 0x67, 0x65, 0x74, 0x7d, 0x22, 0x71, 0x0a,
	0x05, 0x4d, 0x6f, 0x64, 0x65, 0x6c, 0x12, 0x12, 0x0a, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x18, 0x01,
	0x20, 0x01, 0x28, 0x09, 0x52, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x3a, 0x54, 0xea, 0x41, 0x51, 0x0a,
	0x23, 0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65, 0x6f, 0x73, 0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e,
	0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x61, 0x70, 0x69, 0x73, 0x2e, 0x63, 0x6f, 0x6d, 0x2f, 0x4d,
	0x6f, 0x64, 0x65, 0x6c, 0x12, 0x2a, 0x62, 0x75, 0x69, 0x6c, 0x64, 0x54, 0x61, 0x72, 0x67, 0x65,
	0x74, 0x73, 0x2f, 0x7b, 0x62, 0x75, 0x69, 0x6c, 0x64, 0x5f, 0x74, 0x61, 0x72, 0x67, 0x65, 0x74,
	0x7d, 0x2f, 0x6d, 0x6f, 0x64, 0x65, 0x6c, 0x73, 0x2f, 0x7b, 0x6d, 0x6f, 0x64, 0x65, 0x6c, 0x7d,
	0x22, 0x65, 0x0a, 0x09, 0x4d, 0x69, 0x6c, 0x65, 0x73, 0x74, 0x6f, 0x6e, 0x65, 0x12, 0x12, 0x0a,
	0x04, 0x6e, 0x61, 0x6d, 0x65, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x52, 0x04, 0x6e, 0x61, 0x6d,
	0x65, 0x3a, 0x44, 0xea, 0x41, 0x41, 0x0a, 0x27, 0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65, 0x6f, 0x73,
	0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x61, 0x70, 0x69,
	0x73, 0x2e, 0x63, 0x6f, 0x6d, 0x2f, 0x4d, 0x69, 0x6c, 0x65, 0x73, 0x74, 0x6f, 0x6e, 0x65, 0x12,
	0x16, 0x6d, 0x69, 0x6c, 0x65, 0x73, 0x74, 0x6f, 0x6e, 0x65, 0x73, 0x2f, 0x7b, 0x6d, 0x69, 0x6c,
	0x65, 0x73, 0x74, 0x6f, 0x6e, 0x65, 0x7d, 0x22, 0x80, 0x05, 0x0a, 0x05, 0x42, 0x75, 0x69, 0x6c,
	0x64, 0x12, 0x12, 0x0a, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x52,
	0x04, 0x6e, 0x61, 0x6d, 0x65, 0x12, 0x4a, 0x0a, 0x09, 0x6d, 0x69, 0x6c, 0x65, 0x73, 0x74, 0x6f,
	0x6e, 0x65, 0x18, 0x02, 0x20, 0x01, 0x28, 0x09, 0x42, 0x2c, 0xfa, 0x41, 0x29, 0x0a, 0x27, 0x63,
	0x68, 0x72, 0x6f, 0x6d, 0x65, 0x6f, 0x73, 0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e, 0x67, 0x6f,
	0x6f, 0x67, 0x6c, 0x65, 0x61, 0x70, 0x69, 0x73, 0x2e, 0x63, 0x6f, 0x6d, 0x2f, 0x4d, 0x69, 0x6c,
	0x65, 0x73, 0x74, 0x6f, 0x6e, 0x65, 0x52, 0x09, 0x6d, 0x69, 0x6c, 0x65, 0x73, 0x74, 0x6f, 0x6e,
	0x65, 0x12, 0x23, 0x0a, 0x0d, 0x62, 0x75, 0x69, 0x6c, 0x64, 0x5f, 0x76, 0x65, 0x72, 0x73, 0x69,
	0x6f, 0x6e, 0x18, 0x03, 0x20, 0x01, 0x28, 0x09, 0x52, 0x0c, 0x62, 0x75, 0x69, 0x6c, 0x64, 0x56,
	0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x12, 0x49, 0x0a, 0x06, 0x73, 0x74, 0x61, 0x74, 0x75, 0x73,
	0x18, 0x04, 0x20, 0x01, 0x28, 0x0e, 0x32, 0x31, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e,
	0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65, 0x6f, 0x73, 0x2e, 0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e,
	0x76, 0x31, 0x62, 0x65, 0x74, 0x61, 0x31, 0x2e, 0x42, 0x75, 0x69, 0x6c, 0x64, 0x2e, 0x42, 0x75,
	0x69, 0x6c, 0x64, 0x53, 0x74, 0x61, 0x74, 0x75, 0x73, 0x52, 0x06, 0x73, 0x74, 0x61, 0x74, 0x75,
	0x73, 0x12, 0x43, 0x0a, 0x04, 0x74, 0x79, 0x70, 0x65, 0x18, 0x05, 0x20, 0x01, 0x28, 0x0e, 0x32,
	0x2f, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65, 0x6f,
	0x73, 0x2e, 0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e, 0x76, 0x31, 0x62, 0x65, 0x74, 0x61, 0x31,
	0x2e, 0x42, 0x75, 0x69, 0x6c, 0x64, 0x2e, 0x42, 0x75, 0x69, 0x6c, 0x64, 0x54, 0x79, 0x70, 0x65,
	0x52, 0x04, 0x74, 0x79, 0x70, 0x65, 0x12, 0x16, 0x0a, 0x06, 0x62, 0x72, 0x61, 0x6e, 0x63, 0x68,
	0x18, 0x06, 0x20, 0x01, 0x28, 0x09, 0x52, 0x06, 0x62, 0x72, 0x61, 0x6e, 0x63, 0x68, 0x12, 0x2e,
	0x0a, 0x13, 0x72, 0x77, 0x5f, 0x66, 0x69, 0x72, 0x6d, 0x77, 0x61, 0x72, 0x65, 0x5f, 0x76, 0x65,
	0x72, 0x73, 0x69, 0x6f, 0x6e, 0x18, 0x07, 0x20, 0x01, 0x28, 0x09, 0x52, 0x11, 0x72, 0x77, 0x46,
	0x69, 0x72, 0x6d, 0x77, 0x61, 0x72, 0x65, 0x56, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x12, 0x16,
	0x0a, 0x06, 0x6c, 0x61, 0x62, 0x65, 0x6c, 0x73, 0x18, 0x08, 0x20, 0x03, 0x28, 0x09, 0x52, 0x06,
	0x6c, 0x61, 0x62, 0x65, 0x6c, 0x73, 0x22, 0x59, 0x0a, 0x0b, 0x42, 0x75, 0x69, 0x6c, 0x64, 0x53,
	0x74, 0x61, 0x74, 0x75, 0x73, 0x12, 0x1c, 0x0a, 0x18, 0x42, 0x55, 0x49, 0x4c, 0x44, 0x5f, 0x53,
	0x54, 0x41, 0x54, 0x55, 0x53, 0x5f, 0x55, 0x4e, 0x53, 0x50, 0x45, 0x43, 0x49, 0x46, 0x49, 0x45,
	0x44, 0x10, 0x00, 0x12, 0x08, 0x0a, 0x04, 0x50, 0x41, 0x53, 0x53, 0x10, 0x01, 0x12, 0x08, 0x0a,
	0x04, 0x46, 0x41, 0x49, 0x4c, 0x10, 0x02, 0x12, 0x0b, 0x0a, 0x07, 0x52, 0x55, 0x4e, 0x4e, 0x49,
	0x4e, 0x47, 0x10, 0x03, 0x12, 0x0b, 0x0a, 0x07, 0x41, 0x42, 0x4f, 0x52, 0x54, 0x45, 0x44, 0x10,
	0x04, 0x22, 0x42, 0x0a, 0x09, 0x42, 0x75, 0x69, 0x6c, 0x64, 0x54, 0x79, 0x70, 0x65, 0x12, 0x1a,
	0x0a, 0x16, 0x42, 0x55, 0x49, 0x4c, 0x44, 0x5f, 0x54, 0x59, 0x50, 0x45, 0x5f, 0x55, 0x4e, 0x53,
	0x50, 0x45, 0x43, 0x49, 0x46, 0x49, 0x45, 0x44, 0x10, 0x00, 0x12, 0x0b, 0x0a, 0x07, 0x52, 0x45,
	0x4c, 0x45, 0x41, 0x53, 0x45, 0x10, 0x01, 0x12, 0x0c, 0x0a, 0x08, 0x46, 0x49, 0x52, 0x4d, 0x57,
	0x41, 0x52, 0x45, 0x10, 0x02, 0x3a, 0x63, 0xea, 0x41, 0x60, 0x0a, 0x23, 0x63, 0x68, 0x72, 0x6f,
	0x6d, 0x65, 0x6f, 0x73, 0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c,
	0x65, 0x61, 0x70, 0x69, 0x73, 0x2e, 0x63, 0x6f, 0x6d, 0x2f, 0x42, 0x75, 0x69, 0x6c, 0x64, 0x12,
	0x39, 0x62, 0x75, 0x69, 0x6c, 0x64, 0x54, 0x61, 0x72, 0x67, 0x65, 0x74, 0x73, 0x2f, 0x7b, 0x62,
	0x75, 0x69, 0x6c, 0x64, 0x5f, 0x74, 0x61, 0x72, 0x67, 0x65, 0x74, 0x7d, 0x2f, 0x6d, 0x6f, 0x64,
	0x65, 0x6c, 0x73, 0x2f, 0x7b, 0x6d, 0x6f, 0x64, 0x65, 0x6c, 0x7d, 0x2f, 0x62, 0x75, 0x69, 0x6c,
	0x64, 0x73, 0x2f, 0x7b, 0x62, 0x75, 0x69, 0x6c, 0x64, 0x7d, 0x22, 0xb5, 0x02, 0x0a, 0x0d, 0x42,
	0x75, 0x69, 0x6c, 0x64, 0x41, 0x72, 0x74, 0x69, 0x66, 0x61, 0x63, 0x74, 0x12, 0x12, 0x0a, 0x04,
	0x6e, 0x61, 0x6d, 0x65, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x52, 0x04, 0x6e, 0x61, 0x6d, 0x65,
	0x12, 0x3e, 0x0a, 0x05, 0x62, 0x75, 0x69, 0x6c, 0x64, 0x18, 0x02, 0x20, 0x01, 0x28, 0x09, 0x42,
	0x28, 0xfa, 0x41, 0x25, 0x0a, 0x23, 0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65, 0x6f, 0x73, 0x6d, 0x6f,
	0x62, 0x6c, 0x61, 0x62, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x61, 0x70, 0x69, 0x73, 0x2e,
	0x63, 0x6f, 0x6d, 0x2f, 0x42, 0x75, 0x69, 0x6c, 0x64, 0x52, 0x05, 0x62, 0x75, 0x69, 0x6c, 0x64,
	0x12, 0x16, 0x0a, 0x06, 0x62, 0x75, 0x63, 0x6b, 0x65, 0x74, 0x18, 0x03, 0x20, 0x01, 0x28, 0x09,
	0x52, 0x06, 0x62, 0x75, 0x63, 0x6b, 0x65, 0x74, 0x12, 0x12, 0x0a, 0x04, 0x70, 0x61, 0x74, 0x68,
	0x18, 0x04, 0x20, 0x01, 0x28, 0x09, 0x52, 0x04, 0x70, 0x61, 0x74, 0x68, 0x12, 0x21, 0x0a, 0x0c,
	0x6f, 0x62, 0x6a, 0x65, 0x63, 0x74, 0x5f, 0x63, 0x6f, 0x75, 0x6e, 0x74, 0x18, 0x05, 0x20, 0x01,
	0x28, 0x0d, 0x52, 0x0b, 0x6f, 0x62, 0x6a, 0x65, 0x63, 0x74, 0x43, 0x6f, 0x75, 0x6e, 0x74, 0x3a,
	0x80, 0x01, 0xea, 0x41, 0x7d, 0x0a, 0x2b, 0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65, 0x6f, 0x73, 0x6d,
	0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x61, 0x70, 0x69, 0x73,
	0x2e, 0x63, 0x6f, 0x6d, 0x2f, 0x42, 0x75, 0x69, 0x6c, 0x64, 0x41, 0x72, 0x74, 0x69, 0x66, 0x61,
	0x63, 0x74, 0x12, 0x4e, 0x62, 0x75, 0x69, 0x6c, 0x64, 0x54, 0x61, 0x72, 0x67, 0x65, 0x74, 0x73,
	0x2f, 0x7b, 0x62, 0x75, 0x69, 0x6c, 0x64, 0x5f, 0x74, 0x61, 0x72, 0x67, 0x65, 0x74, 0x7d, 0x2f,
	0x6d, 0x6f, 0x64, 0x65, 0x6c, 0x73, 0x2f, 0x7b, 0x6d, 0x6f, 0x64, 0x65, 0x6c, 0x7d, 0x2f, 0x62,
	0x75, 0x69, 0x6c, 0x64, 0x73, 0x2f, 0x7b, 0x62, 0x75, 0x69, 0x6c, 0x64, 0x7d, 0x2f, 0x61, 0x72,
	0x74, 0x69, 0x66, 0x61, 0x63, 0x74, 0x73, 0x2f, 0x7b, 0x61, 0x72, 0x74, 0x69, 0x66, 0x61, 0x63,
	0x74, 0x7d, 0x22, 0xd3, 0x03, 0x0a, 0x0a, 0x43, 0x6c, 0x6f, 0x75, 0x64, 0x42, 0x75, 0x69, 0x6c,
	0x64, 0x12, 0x13, 0x0a, 0x02, 0x69, 0x64, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x42, 0x03, 0xe0,
	0x41, 0x03, 0x52, 0x02, 0x69, 0x64, 0x12, 0x4d, 0x0a, 0x06, 0x73, 0x74, 0x61, 0x74, 0x75, 0x73,
	0x18, 0x02, 0x20, 0x01, 0x28, 0x0e, 0x32, 0x30, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e,
	0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65, 0x6f, 0x73, 0x2e, 0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e,
	0x76, 0x31, 0x62, 0x65, 0x74, 0x61, 0x31, 0x2e, 0x43, 0x6c, 0x6f, 0x75, 0x64, 0x42, 0x75, 0x69,
	0x6c, 0x64, 0x2e, 0x53, 0x74, 0x61, 0x74, 0x65, 0x42, 0x03, 0xe0, 0x41, 0x03, 0x52, 0x06, 0x73,
	0x74, 0x61, 0x74, 0x75, 0x73, 0x12, 0x40, 0x0a, 0x0b, 0x63, 0x72, 0x65, 0x61, 0x74, 0x65, 0x5f,
	0x74, 0x69, 0x6d, 0x65, 0x18, 0x03, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x1a, 0x2e, 0x67, 0x6f, 0x6f,
	0x67, 0x6c, 0x65, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x62, 0x75, 0x66, 0x2e, 0x54, 0x69, 0x6d,
	0x65, 0x73, 0x74, 0x61, 0x6d, 0x70, 0x42, 0x03, 0xe0, 0x41, 0x03, 0x52, 0x0a, 0x63, 0x72, 0x65,
	0x61, 0x74, 0x65, 0x54, 0x69, 0x6d, 0x65, 0x12, 0x3e, 0x0a, 0x0a, 0x73, 0x74, 0x61, 0x72, 0x74,
	0x5f, 0x74, 0x69, 0x6d, 0x65, 0x18, 0x04, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x1a, 0x2e, 0x67, 0x6f,
	0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x62, 0x75, 0x66, 0x2e, 0x54, 0x69,
	0x6d, 0x65, 0x73, 0x74, 0x61, 0x6d, 0x70, 0x42, 0x03, 0xe0, 0x41, 0x03, 0x52, 0x09, 0x73, 0x74,
	0x61, 0x72, 0x74, 0x54, 0x69, 0x6d, 0x65, 0x12, 0x40, 0x0a, 0x0b, 0x66, 0x69, 0x6e, 0x69, 0x73,
	0x68, 0x5f, 0x74, 0x69, 0x6d, 0x65, 0x18, 0x05, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x1a, 0x2e, 0x67,
	0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x62, 0x75, 0x66, 0x2e, 0x54,
	0x69, 0x6d, 0x65, 0x73, 0x74, 0x61, 0x6d, 0x70, 0x42, 0x03, 0xe0, 0x41, 0x03, 0x52, 0x0a, 0x66,
	0x69, 0x6e, 0x69, 0x73, 0x68, 0x54, 0x69, 0x6d, 0x65, 0x22, 0x9c, 0x01, 0x0a, 0x05, 0x53, 0x74,
	0x61, 0x74, 0x65, 0x12, 0x15, 0x0a, 0x11, 0x53, 0x54, 0x41, 0x54, 0x45, 0x5f, 0x55, 0x4e, 0x53,
	0x50, 0x45, 0x43, 0x49, 0x46, 0x49, 0x45, 0x44, 0x10, 0x00, 0x12, 0x0a, 0x0a, 0x06, 0x51, 0x55,
	0x45, 0x55, 0x45, 0x44, 0x10, 0x01, 0x12, 0x0b, 0x0a, 0x07, 0x50, 0x45, 0x4e, 0x44, 0x49, 0x4e,
	0x47, 0x10, 0x02, 0x12, 0x0b, 0x0a, 0x07, 0x57, 0x4f, 0x52, 0x4b, 0x49, 0x4e, 0x47, 0x10, 0x03,
	0x12, 0x0d, 0x0a, 0x09, 0x53, 0x55, 0x43, 0x43, 0x45, 0x45, 0x44, 0x45, 0x44, 0x10, 0x04, 0x12,
	0x0a, 0x0a, 0x06, 0x46, 0x41, 0x49, 0x4c, 0x45, 0x44, 0x10, 0x05, 0x12, 0x12, 0x0a, 0x0e, 0x49,
	0x4e, 0x54, 0x45, 0x52, 0x4e, 0x41, 0x4c, 0x5f, 0x45, 0x52, 0x52, 0x4f, 0x52, 0x10, 0x06, 0x12,
	0x0b, 0x0a, 0x07, 0x54, 0x49, 0x4d, 0x45, 0x4f, 0x55, 0x54, 0x10, 0x07, 0x12, 0x0d, 0x0a, 0x09,
	0x43, 0x41, 0x4e, 0x43, 0x45, 0x4c, 0x4c, 0x45, 0x44, 0x10, 0x08, 0x12, 0x0b, 0x0a, 0x07, 0x45,
	0x58, 0x50, 0x49, 0x52, 0x45, 0x44, 0x10, 0x09, 0x22, 0x85, 0x04, 0x0a, 0x07, 0x53, 0x65, 0x73,
	0x73, 0x69, 0x6f, 0x6e, 0x12, 0x17, 0x0a, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x18, 0x01, 0x20, 0x01,
	0x28, 0x09, 0x42, 0x03, 0xe0, 0x41, 0x08, 0x52, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x12, 0x20, 0x0a,
	0x09, 0x73, 0x61, 0x74, 0x6c, 0x61, 0x62, 0x5f, 0x69, 0x64, 0x18, 0x02, 0x20, 0x01, 0x28, 0x09,
	0x42, 0x03, 0xe0, 0x41, 0x01, 0x52, 0x08, 0x73, 0x61, 0x74, 0x6c, 0x61, 0x62, 0x49, 0x64, 0x12,
	0x5f, 0x0a, 0x0a, 0x64, 0x69, 0x6d, 0x65, 0x6e, 0x73, 0x69, 0x6f, 0x6e, 0x73, 0x18, 0x03, 0x20,
	0x03, 0x28, 0x0b, 0x32, 0x37, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x63, 0x68, 0x72,
	0x6f, 0x6d, 0x65, 0x6f, 0x73, 0x2e, 0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e, 0x76, 0x31, 0x62,
	0x65, 0x74, 0x61, 0x31, 0x2e, 0x53, 0x65, 0x73, 0x73, 0x69, 0x6f, 0x6e, 0x2e, 0x44, 0x69, 0x6d,
	0x65, 0x6e, 0x73, 0x69, 0x6f, 0x6e, 0x73, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x42, 0x06, 0xe0, 0x41,
	0x02, 0xe0, 0x41, 0x04, 0x52, 0x0a, 0x64, 0x69, 0x6d, 0x65, 0x6e, 0x73, 0x69, 0x6f, 0x6e, 0x73,
	0x12, 0x49, 0x0a, 0x07, 0x74, 0x69, 0x6d, 0x65, 0x6f, 0x75, 0x74, 0x18, 0x04, 0x20, 0x01, 0x28,
	0x0b, 0x32, 0x27, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x63, 0x68, 0x72, 0x6f, 0x6d,
	0x65, 0x6f, 0x73, 0x2e, 0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e, 0x76, 0x31, 0x62, 0x65, 0x74,
	0x61, 0x31, 0x2e, 0x54, 0x69, 0x6d, 0x65, 0x6f, 0x75, 0x74, 0x42, 0x06, 0xe0, 0x41, 0x01, 0xe0,
	0x41, 0x04, 0x52, 0x07, 0x74, 0x69, 0x6d, 0x65, 0x6f, 0x75, 0x74, 0x12, 0x27, 0x0a, 0x0b, 0x73,
	0x68, 0x61, 0x72, 0x64, 0x5f, 0x63, 0x6f, 0x75, 0x6e, 0x74, 0x18, 0x05, 0x20, 0x01, 0x28, 0x05,
	0x42, 0x06, 0xe0, 0x41, 0x01, 0xe0, 0x41, 0x04, 0x52, 0x0a, 0x73, 0x68, 0x61, 0x72, 0x64, 0x43,
	0x6f, 0x75, 0x6e, 0x74, 0x12, 0x58, 0x0a, 0x0d, 0x74, 0x72, 0x61, 0x64, 0x65, 0x66, 0x65, 0x64,
	0x5f, 0x74, 0x65, 0x73, 0x74, 0x18, 0x06, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x2c, 0x2e, 0x67, 0x6f,
	0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65, 0x6f, 0x73, 0x2e, 0x6d, 0x6f,
	0x62, 0x6c, 0x61, 0x62, 0x2e, 0x76, 0x31, 0x62, 0x65, 0x74, 0x61, 0x31, 0x2e, 0x54, 0x72, 0x61,
	0x64, 0x65, 0x66, 0x65, 0x64, 0x54, 0x65, 0x73, 0x74, 0x42, 0x03, 0xe0, 0x41, 0x04, 0x48, 0x00,
	0x52, 0x0c, 0x74, 0x72, 0x61, 0x64, 0x65, 0x66, 0x65, 0x64, 0x54, 0x65, 0x73, 0x74, 0x1a, 0x3d,
	0x0a, 0x0f, 0x44, 0x69, 0x6d, 0x65, 0x6e, 0x73, 0x69, 0x6f, 0x6e, 0x73, 0x45, 0x6e, 0x74, 0x72,
	0x79, 0x12, 0x10, 0x0a, 0x03, 0x6b, 0x65, 0x79, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x52, 0x03,
	0x6b, 0x65, 0x79, 0x12, 0x14, 0x0a, 0x05, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x18, 0x02, 0x20, 0x01,
	0x28, 0x09, 0x52, 0x05, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x3a, 0x02, 0x38, 0x01, 0x3a, 0x49, 0xea,
	0x41, 0x46, 0x0a, 0x1d, 0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c,
	0x65, 0x61, 0x70, 0x69, 0x73, 0x2e, 0x63, 0x6f, 0x6d, 0x2f, 0x53, 0x65, 0x73, 0x73, 0x69, 0x6f,
	0x6e, 0x12, 0x12, 0x73, 0x65, 0x73, 0x73, 0x69, 0x6f, 0x6e, 0x73, 0x2f, 0x7b, 0x73, 0x65, 0x73,
	0x73, 0x69, 0x6f, 0x6e, 0x7d, 0x2a, 0x08, 0x73, 0x65, 0x73, 0x73, 0x69, 0x6f, 0x6e, 0x73, 0x32,
	0x07, 0x73, 0x65, 0x73, 0x73, 0x69, 0x6f, 0x6e, 0x42, 0x06, 0x0a, 0x04, 0x74, 0x65, 0x73, 0x74,
	0x22, 0xd2, 0x01, 0x0a, 0x07, 0x54, 0x69, 0x6d, 0x65, 0x6f, 0x75, 0x74, 0x12, 0x3f, 0x0a, 0x0b,
	0x6a, 0x6f, 0x62, 0x5f, 0x74, 0x69, 0x6d, 0x65, 0x6f, 0x75, 0x74, 0x18, 0x01, 0x20, 0x01, 0x28,
	0x0b, 0x32, 0x19, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f,
	0x62, 0x75, 0x66, 0x2e, 0x44, 0x75, 0x72, 0x61, 0x74, 0x69, 0x6f, 0x6e, 0x42, 0x03, 0xe0, 0x41,
	0x01, 0x52, 0x0a, 0x6a, 0x6f, 0x62, 0x54, 0x69, 0x6d, 0x65, 0x6f, 0x75, 0x74, 0x12, 0x41, 0x0a,
	0x0c, 0x74, 0x65, 0x73, 0x74, 0x5f, 0x74, 0x69, 0x6d, 0x65, 0x6f, 0x75, 0x74, 0x18, 0x02, 0x20,
	0x01, 0x28, 0x0b, 0x32, 0x19, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x70, 0x72, 0x6f,
	0x74, 0x6f, 0x62, 0x75, 0x66, 0x2e, 0x44, 0x75, 0x72, 0x61, 0x74, 0x69, 0x6f, 0x6e, 0x42, 0x03,
	0xe0, 0x41, 0x01, 0x52, 0x0b, 0x74, 0x65, 0x73, 0x74, 0x54, 0x69, 0x6d, 0x65, 0x6f, 0x75, 0x74,
	0x12, 0x43, 0x0a, 0x0d, 0x73, 0x74, 0x61, 0x72, 0x74, 0x5f, 0x74, 0x69, 0x6d, 0x65, 0x6f, 0x75,
	0x74, 0x18, 0x03, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x19, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65,
	0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x62, 0x75, 0x66, 0x2e, 0x44, 0x75, 0x72, 0x61, 0x74, 0x69,
	0x6f, 0x6e, 0x42, 0x03, 0xe0, 0x41, 0x01, 0x52, 0x0c, 0x73, 0x74, 0x61, 0x72, 0x74, 0x54, 0x69,
	0x6d, 0x65, 0x6f, 0x75, 0x74, 0x22, 0x2d, 0x0a, 0x0c, 0x54, 0x72, 0x61, 0x64, 0x65, 0x66, 0x65,
	0x64, 0x54, 0x65, 0x73, 0x74, 0x12, 0x1d, 0x0a, 0x07, 0x63, 0x6f, 0x6d, 0x6d, 0x61, 0x6e, 0x64,
	0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x42, 0x03, 0xe0, 0x41, 0x02, 0x52, 0x07, 0x63, 0x6f, 0x6d,
	0x6d, 0x61, 0x6e, 0x64, 0x22, 0xca, 0x13, 0x0a, 0x0a, 0x54, 0x65, 0x73, 0x74, 0x45, 0x66, 0x66,
	0x6f, 0x72, 0x74, 0x12, 0x17, 0x0a, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x18, 0x01, 0x20, 0x01, 0x28,
	0x09, 0x42, 0x03, 0xe0, 0x41, 0x08, 0x52, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x12, 0x29, 0x0a, 0x0e,
	0x74, 0x65, 0x73, 0x74, 0x5f, 0x65, 0x66, 0x66, 0x6f, 0x72, 0x74, 0x5f, 0x69, 0x64, 0x18, 0x02,
	0x20, 0x01, 0x28, 0x09, 0x42, 0x03, 0xe0, 0x41, 0x03, 0x52, 0x0c, 0x74, 0x65, 0x73, 0x74, 0x45,
	0x66, 0x66, 0x6f, 0x72, 0x74, 0x49, 0x64, 0x12, 0x20, 0x0a, 0x09, 0x73, 0x61, 0x74, 0x6c, 0x61,
	0x62, 0x5f, 0x69, 0x64, 0x18, 0x03, 0x20, 0x01, 0x28, 0x09, 0x42, 0x03, 0xe0, 0x41, 0x01, 0x52,
	0x08, 0x73, 0x61, 0x74, 0x6c, 0x61, 0x62, 0x49, 0x64, 0x12, 0x58, 0x0a, 0x0b, 0x62, 0x6f, 0x61,
	0x72, 0x64, 0x5f, 0x6d, 0x6f, 0x64, 0x65, 0x6c, 0x18, 0x04, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x35,
	0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65, 0x6f, 0x73,
	0x2e, 0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e, 0x76, 0x31, 0x62, 0x65, 0x74, 0x61, 0x31, 0x2e,
	0x54, 0x65, 0x73, 0x74, 0x45, 0x66, 0x66, 0x6f, 0x72, 0x74, 0x2e, 0x42, 0x6f, 0x61, 0x72, 0x64,
	0x4d, 0x6f, 0x64, 0x65, 0x6c, 0x48, 0x00, 0x52, 0x0a, 0x62, 0x6f, 0x61, 0x72, 0x64, 0x4d, 0x6f,
	0x64, 0x65, 0x6c, 0x12, 0x4a, 0x0a, 0x05, 0x70, 0x6f, 0x6f, 0x6c, 0x73, 0x18, 0x05, 0x20, 0x03,
	0x28, 0x0b, 0x32, 0x2f, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x63, 0x68, 0x72, 0x6f,
	0x6d, 0x65, 0x6f, 0x73, 0x2e, 0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e, 0x76, 0x31, 0x62, 0x65,
	0x74, 0x61, 0x31, 0x2e, 0x54, 0x65, 0x73, 0x74, 0x45, 0x66, 0x66, 0x6f, 0x72, 0x74, 0x2e, 0x50,
	0x6f, 0x6f, 0x6c, 0x42, 0x03, 0xe0, 0x41, 0x02, 0x52, 0x05, 0x70, 0x6f, 0x6f, 0x6c, 0x73, 0x12,
	0x20, 0x0a, 0x09, 0x74, 0x65, 0x73, 0x74, 0x5f, 0x70, 0x6c, 0x61, 0x6e, 0x18, 0x06, 0x20, 0x01,
	0x28, 0x09, 0x42, 0x03, 0xe0, 0x41, 0x02, 0x52, 0x08, 0x74, 0x65, 0x73, 0x74, 0x50, 0x6c, 0x61,
	0x6e, 0x12, 0x59, 0x0a, 0x07, 0x61, 0x6e, 0x64, 0x72, 0x6f, 0x69, 0x64, 0x18, 0x07, 0x20, 0x01,
	0x28, 0x0b, 0x32, 0x3d, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x63, 0x68, 0x72, 0x6f,
	0x6d, 0x65, 0x6f, 0x73, 0x2e, 0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e, 0x76, 0x31, 0x62, 0x65,
	0x74, 0x61, 0x31, 0x2e, 0x54, 0x65, 0x73, 0x74, 0x45, 0x66, 0x66, 0x6f, 0x72, 0x74, 0x2e, 0x41,
	0x6e, 0x64, 0x72, 0x6f, 0x69, 0x64, 0x42, 0x75, 0x69, 0x6c, 0x64, 0x54, 0x61, 0x72, 0x67, 0x65,
	0x74, 0x48, 0x01, 0x52, 0x07, 0x61, 0x6e, 0x64, 0x72, 0x6f, 0x69, 0x64, 0x12, 0x4b, 0x0a, 0x05,
	0x73, 0x74, 0x61, 0x74, 0x65, 0x18, 0x08, 0x20, 0x01, 0x28, 0x0e, 0x32, 0x30, 0x2e, 0x67, 0x6f,
	0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65, 0x6f, 0x73, 0x2e, 0x6d, 0x6f,
	0x62, 0x6c, 0x61, 0x62, 0x2e, 0x76, 0x31, 0x62, 0x65, 0x74, 0x61, 0x31, 0x2e, 0x54, 0x65, 0x73,
	0x74, 0x45, 0x66, 0x66, 0x6f, 0x72, 0x74, 0x2e, 0x53, 0x74, 0x61, 0x74, 0x65, 0x42, 0x03, 0xe0,
	0x41, 0x03, 0x52, 0x05, 0x73, 0x74, 0x61, 0x74, 0x65, 0x12, 0x40, 0x0a, 0x0b, 0x63, 0x72, 0x65,
	0x61, 0x74, 0x65, 0x5f, 0x74, 0x69, 0x6d, 0x65, 0x18, 0x09, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x1a,
	0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x62, 0x75, 0x66,
	0x2e, 0x54, 0x69, 0x6d, 0x65, 0x73, 0x74, 0x61, 0x6d, 0x70, 0x42, 0x03, 0xe0, 0x41, 0x03, 0x52,
	0x0a, 0x63, 0x72, 0x65, 0x61, 0x74, 0x65, 0x54, 0x69, 0x6d, 0x65, 0x12, 0x26, 0x0a, 0x0c, 0x74,
	0x65, 0x73, 0x74, 0x68, 0x61, 0x75, 0x73, 0x5f, 0x75, 0x72, 0x6c, 0x18, 0x0a, 0x20, 0x01, 0x28,
	0x09, 0x42, 0x03, 0xe0, 0x41, 0x03, 0x52, 0x0b, 0x74, 0x65, 0x73, 0x74, 0x68, 0x61, 0x75, 0x73,
	0x55, 0x72, 0x6c, 0x12, 0x69, 0x0a, 0x10, 0x66, 0x69, 0x72, 0x6d, 0x77, 0x61, 0x72, 0x65, 0x5f,
	0x63, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x73, 0x18, 0x0b, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x39, 0x2e,
	0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65, 0x6f, 0x73, 0x2e,
	0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e, 0x76, 0x31, 0x62, 0x65, 0x74, 0x61, 0x31, 0x2e, 0x54,
	0x65, 0x73, 0x74, 0x45, 0x66, 0x66, 0x6f, 0x72, 0x74, 0x2e, 0x46, 0x69, 0x72, 0x6d, 0x77, 0x61,
	0x72, 0x65, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x42, 0x03, 0xe0, 0x41, 0x01, 0x52, 0x0f, 0x66,
	0x69, 0x72, 0x6d, 0x77, 0x61, 0x72, 0x65, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x73, 0x1a, 0x42,
	0x0a, 0x0a, 0x42, 0x6f, 0x61, 0x72, 0x64, 0x4d, 0x6f, 0x64, 0x65, 0x6c, 0x12, 0x19, 0x0a, 0x05,
	0x62, 0x6f, 0x61, 0x72, 0x64, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x42, 0x03, 0xe0, 0x41, 0x02,
	0x52, 0x05, 0x62, 0x6f, 0x61, 0x72, 0x64, 0x12, 0x19, 0x0a, 0x05, 0x6d, 0x6f, 0x64, 0x65, 0x6c,
	0x18, 0x02, 0x20, 0x01, 0x28, 0x09, 0x42, 0x03, 0xe0, 0x41, 0x02, 0x52, 0x05, 0x6d, 0x6f, 0x64,
	0x65, 0x6c, 0x1a, 0xd1, 0x01, 0x0a, 0x04, 0x50, 0x6f, 0x6f, 0x6c, 0x12, 0x19, 0x0a, 0x05, 0x6c,
	0x61, 0x62, 0x65, 0x6c, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x42, 0x03, 0xe0, 0x41, 0x02, 0x52,
	0x05, 0x6c, 0x61, 0x62, 0x65, 0x6c, 0x12, 0x51, 0x0a, 0x04, 0x74, 0x79, 0x70, 0x65, 0x18, 0x02,
	0x20, 0x01, 0x28, 0x0e, 0x32, 0x38, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x63, 0x68,
	0x72, 0x6f, 0x6d, 0x65, 0x6f, 0x73, 0x2e, 0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e, 0x76, 0x31,
	0x62, 0x65, 0x74, 0x61, 0x31, 0x2e, 0x54, 0x65, 0x73, 0x74, 0x45, 0x66, 0x66, 0x6f, 0x72, 0x74,
	0x2e, 0x50, 0x6f, 0x6f, 0x6c, 0x2e, 0x50, 0x6f, 0x6f, 0x6c, 0x54, 0x79, 0x70, 0x65, 0x42, 0x03,
	0xe0, 0x41, 0x02, 0x52, 0x04, 0x74, 0x79, 0x70, 0x65, 0x22, 0x5b, 0x0a, 0x08, 0x50, 0x6f, 0x6f,
	0x6c, 0x54, 0x79, 0x70, 0x65, 0x12, 0x19, 0x0a, 0x15, 0x50, 0x4f, 0x4f, 0x4c, 0x5f, 0x54, 0x59,
	0x50, 0x45, 0x5f, 0x55, 0x4e, 0x53, 0x50, 0x45, 0x43, 0x49, 0x46, 0x49, 0x45, 0x44, 0x10, 0x00,
	0x12, 0x10, 0x0a, 0x0c, 0x44, 0x45, 0x46, 0x41, 0x55, 0x4c, 0x54, 0x5f, 0x50, 0x4f, 0x4f, 0x4c,
	0x10, 0x01, 0x12, 0x0b, 0x0a, 0x07, 0x46, 0x41, 0x46, 0x54, 0x5f, 0x50, 0x44, 0x10, 0x02, 0x12,
	0x15, 0x0a, 0x11, 0x45, 0x58, 0x54, 0x45, 0x4e, 0x44, 0x45, 0x44, 0x5f, 0x44, 0x55, 0x52, 0x41,
	0x54, 0x49, 0x4f, 0x4e, 0x10, 0x03, 0x1a, 0xc6, 0x01, 0x0a, 0x12, 0x41, 0x6e, 0x64, 0x72, 0x6f,
	0x69, 0x64, 0x42, 0x75, 0x69, 0x6c, 0x64, 0x54, 0x61, 0x72, 0x67, 0x65, 0x74, 0x12, 0x1b, 0x0a,
	0x06, 0x62, 0x72, 0x61, 0x6e, 0x63, 0x68, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x42, 0x03, 0xe0,
	0x41, 0x02, 0x52, 0x06, 0x62, 0x72, 0x61, 0x6e, 0x63, 0x68, 0x12, 0x2a, 0x0a, 0x0e, 0x72, 0x65,
	0x6c, 0x65, 0x61, 0x73, 0x65, 0x5f, 0x63, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x18, 0x02, 0x20, 0x01,
	0x28, 0x09, 0x42, 0x03, 0xe0, 0x41, 0x02, 0x52, 0x0d, 0x72, 0x65, 0x6c, 0x65, 0x61, 0x73, 0x65,
	0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x12, 0x28, 0x0a, 0x0d, 0x62, 0x75, 0x69, 0x6c, 0x64, 0x5f,
	0x76, 0x61, 0x72, 0x69, 0x61, 0x6e, 0x74, 0x18, 0x03, 0x20, 0x01, 0x28, 0x09, 0x42, 0x03, 0xe0,
	0x41, 0x02, 0x52, 0x0c, 0x62, 0x75, 0x69, 0x6c, 0x64, 0x56, 0x61, 0x72, 0x69, 0x61, 0x6e, 0x74,
	0x12, 0x1e, 0x0a, 0x08, 0x62, 0x75, 0x69, 0x6c, 0x64, 0x5f, 0x69, 0x64, 0x18, 0x04, 0x20, 0x01,
	0x28, 0x09, 0x42, 0x03, 0xe0, 0x41, 0x02, 0x52, 0x07, 0x62, 0x75, 0x69, 0x6c, 0x64, 0x49, 0x64,
	0x12, 0x1d, 0x0a, 0x07, 0x70, 0x72, 0x6f, 0x64, 0x75, 0x63, 0x74, 0x18, 0x05, 0x20, 0x01, 0x28,
	0x09, 0x42, 0x03, 0xe0, 0x41, 0x01, 0x52, 0x07, 0x70, 0x72, 0x6f, 0x64, 0x75, 0x63, 0x74, 0x1a,
	0xae, 0x01, 0x0a, 0x19, 0x46, 0x69, 0x72, 0x6d, 0x77, 0x61, 0x72, 0x65, 0x54, 0x65, 0x73, 0x74,
	0x45, 0x66, 0x66, 0x6f, 0x72, 0x74, 0x56, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x12, 0x28, 0x0a,
	0x0d, 0x6d, 0x61, 0x6a, 0x6f, 0x72, 0x5f, 0x76, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x18, 0x01,
	0x20, 0x01, 0x28, 0x05, 0x42, 0x03, 0xe0, 0x41, 0x02, 0x52, 0x0c, 0x6d, 0x61, 0x6a, 0x6f, 0x72,
	0x56, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x12, 0x28, 0x0a, 0x0d, 0x6d, 0x69, 0x6e, 0x6f, 0x72,
	0x5f, 0x76, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x18, 0x02, 0x20, 0x01, 0x28, 0x05, 0x42, 0x03,
	0xe0, 0x41, 0x02, 0x52, 0x0c, 0x6d, 0x69, 0x6e, 0x6f, 0x72, 0x56, 0x65, 0x72, 0x73, 0x69, 0x6f,
	0x6e, 0x12, 0x26, 0x0a, 0x0c, 0x70, 0x61, 0x74, 0x63, 0x68, 0x5f, 0x6e, 0x75, 0x6d, 0x62, 0x65,
	0x72, 0x18, 0x03, 0x20, 0x01, 0x28, 0x05, 0x42, 0x03, 0xe0, 0x41, 0x02, 0x52, 0x0b, 0x70, 0x61,
	0x74, 0x63, 0x68, 0x4e, 0x75, 0x6d, 0x62, 0x65, 0x72, 0x12, 0x15, 0x0a, 0x03, 0x75, 0x72, 0x69,
	0x18, 0x04, 0x20, 0x01, 0x28, 0x09, 0x42, 0x03, 0xe0, 0x41, 0x01, 0x52, 0x03, 0x75, 0x72, 0x69,
	0x1a, 0xa6, 0x01, 0x0a, 0x14, 0x47, 0x73, 0x63, 0x54, 0x65, 0x73, 0x74, 0x45, 0x66, 0x66, 0x6f,
	0x72, 0x74, 0x56, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x12, 0x28, 0x0a, 0x0d, 0x6d, 0x61, 0x6a,
	0x6f, 0x72, 0x5f, 0x76, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x18, 0x01, 0x20, 0x01, 0x28, 0x05,
	0x42, 0x03, 0xe0, 0x41, 0x02, 0x52, 0x0c, 0x6d, 0x61, 0x6a, 0x6f, 0x72, 0x56, 0x65, 0x72, 0x73,
	0x69, 0x6f, 0x6e, 0x12, 0x28, 0x0a, 0x0d, 0x6d, 0x69, 0x6e, 0x6f, 0x72, 0x5f, 0x76, 0x65, 0x72,
	0x73, 0x69, 0x6f, 0x6e, 0x18, 0x02, 0x20, 0x01, 0x28, 0x05, 0x42, 0x03, 0xe0, 0x41, 0x02, 0x52,
	0x0c, 0x6d, 0x69, 0x6e, 0x6f, 0x72, 0x56, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x12, 0x23, 0x0a,
	0x0a, 0x67, 0x65, 0x6e, 0x65, 0x72, 0x61, 0x74, 0x69, 0x6f, 0x6e, 0x18, 0x03, 0x20, 0x01, 0x28,
	0x05, 0x42, 0x03, 0xe0, 0x41, 0x02, 0x52, 0x0a, 0x67, 0x65, 0x6e, 0x65, 0x72, 0x61, 0x74, 0x69,
	0x6f, 0x6e, 0x12, 0x15, 0x0a, 0x03, 0x75, 0x72, 0x69, 0x18, 0x04, 0x20, 0x01, 0x28, 0x09, 0x42,
	0x03, 0xe0, 0x41, 0x01, 0x52, 0x03, 0x75, 0x72, 0x69, 0x1a, 0xf9, 0x02, 0x0a, 0x0e, 0x46, 0x69,
	0x72, 0x6d, 0x77, 0x61, 0x72, 0x65, 0x54, 0x61, 0x72, 0x67, 0x65, 0x74, 0x12, 0x56, 0x0a, 0x02,
	0x65, 0x63, 0x18, 0x01, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x44, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c,
	0x65, 0x2e, 0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65, 0x6f, 0x73, 0x2e, 0x6d, 0x6f, 0x62, 0x6c, 0x61,
	0x62, 0x2e, 0x76, 0x31, 0x62, 0x65, 0x74, 0x61, 0x31, 0x2e, 0x54, 0x65, 0x73, 0x74, 0x45, 0x66,
	0x66, 0x6f, 0x72, 0x74, 0x2e, 0x46, 0x69, 0x72, 0x6d, 0x77, 0x61, 0x72, 0x65, 0x54, 0x65, 0x73,
	0x74, 0x45, 0x66, 0x66, 0x6f, 0x72, 0x74, 0x56, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x48, 0x00,
	0x52, 0x02, 0x65, 0x63, 0x12, 0x56, 0x0a, 0x02, 0x61, 0x70, 0x18, 0x02, 0x20, 0x01, 0x28, 0x0b,
	0x32, 0x44, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65,
	0x6f, 0x73, 0x2e, 0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e, 0x76, 0x31, 0x62, 0x65, 0x74, 0x61,
	0x31, 0x2e, 0x54, 0x65, 0x73, 0x74, 0x45, 0x66, 0x66, 0x6f, 0x72, 0x74, 0x2e, 0x46, 0x69, 0x72,
	0x6d, 0x77, 0x61, 0x72, 0x65, 0x54, 0x65, 0x73, 0x74, 0x45, 0x66, 0x66, 0x6f, 0x72, 0x74, 0x56,
	0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x48, 0x00, 0x52, 0x02, 0x61, 0x70, 0x12, 0x53, 0x0a, 0x03,
	0x67, 0x73, 0x63, 0x18, 0x03, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x3f, 0x2e, 0x67, 0x6f, 0x6f, 0x67,
	0x6c, 0x65, 0x2e, 0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65, 0x6f, 0x73, 0x2e, 0x6d, 0x6f, 0x62, 0x6c,
	0x61, 0x62, 0x2e, 0x76, 0x31, 0x62, 0x65, 0x74, 0x61, 0x31, 0x2e, 0x54, 0x65, 0x73, 0x74, 0x45,
	0x66, 0x66, 0x6f, 0x72, 0x74, 0x2e, 0x47, 0x73, 0x63, 0x54, 0x65, 0x73, 0x74, 0x45, 0x66, 0x66,
	0x6f, 0x72, 0x74, 0x56, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x48, 0x00, 0x52, 0x03, 0x67, 0x73,
	0x63, 0x12, 0x5c, 0x0a, 0x05, 0x66, 0x70, 0x6d, 0x63, 0x75, 0x18, 0x04, 0x20, 0x01, 0x28, 0x0b,
	0x32, 0x44, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65,
	0x6f, 0x73, 0x2e, 0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e, 0x76, 0x31, 0x62, 0x65, 0x74, 0x61,
	0x31, 0x2e, 0x54, 0x65, 0x73, 0x74, 0x45, 0x66, 0x66, 0x6f, 0x72, 0x74, 0x2e, 0x46, 0x69, 0x72,
	0x6d, 0x77, 0x61, 0x72, 0x65, 0x54, 0x65, 0x73, 0x74, 0x45, 0x66, 0x66, 0x6f, 0x72, 0x74, 0x56,
	0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x48, 0x00, 0x52, 0x05, 0x66, 0x70, 0x6d, 0x63, 0x75, 0x42,
	0x04, 0x0a, 0x02, 0x66, 0x77, 0x1a, 0xde, 0x01, 0x0a, 0x0e, 0x46, 0x69, 0x72, 0x6d, 0x77, 0x61,
	0x72, 0x65, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x12, 0x67, 0x0a, 0x0f, 0x66, 0x69, 0x72, 0x6d,
	0x77, 0x61, 0x72, 0x65, 0x5f, 0x74, 0x61, 0x72, 0x67, 0x65, 0x74, 0x18, 0x01, 0x20, 0x01, 0x28,
	0x0b, 0x32, 0x39, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x63, 0x68, 0x72, 0x6f, 0x6d,
	0x65, 0x6f, 0x73, 0x2e, 0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e, 0x76, 0x31, 0x62, 0x65, 0x74,
	0x61, 0x31, 0x2e, 0x54, 0x65, 0x73, 0x74, 0x45, 0x66, 0x66, 0x6f, 0x72, 0x74, 0x2e, 0x46, 0x69,
	0x72, 0x6d, 0x77, 0x61, 0x72, 0x65, 0x54, 0x61, 0x72, 0x67, 0x65, 0x74, 0x42, 0x03, 0xe0, 0x41,
	0x02, 0x52, 0x0e, 0x66, 0x69, 0x72, 0x6d, 0x77, 0x61, 0x72, 0x65, 0x54, 0x61, 0x72, 0x67, 0x65,
	0x74, 0x12, 0x63, 0x0a, 0x0e, 0x66, 0x69, 0x72, 0x6d, 0x77, 0x61, 0x72, 0x65, 0x5f, 0x74, 0x79,
	0x70, 0x65, 0x73, 0x18, 0x02, 0x20, 0x03, 0x28, 0x0e, 0x32, 0x37, 0x2e, 0x67, 0x6f, 0x6f, 0x67,
	0x6c, 0x65, 0x2e, 0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65, 0x6f, 0x73, 0x2e, 0x6d, 0x6f, 0x62, 0x6c,
	0x61, 0x62, 0x2e, 0x76, 0x31, 0x62, 0x65, 0x74, 0x61, 0x31, 0x2e, 0x54, 0x65, 0x73, 0x74, 0x45,
	0x66, 0x66, 0x6f, 0x72, 0x74, 0x2e, 0x46, 0x69, 0x72, 0x6d, 0x77, 0x61, 0x72, 0x65, 0x54, 0x79,
	0x70, 0x65, 0x42, 0x03, 0xe0, 0x41, 0x02, 0x52, 0x0d, 0x66, 0x69, 0x72, 0x6d, 0x77, 0x61, 0x72,
	0x65, 0x54, 0x79, 0x70, 0x65, 0x73, 0x22, 0xb2, 0x01, 0x0a, 0x05, 0x53, 0x74, 0x61, 0x74, 0x65,
	0x12, 0x15, 0x0a, 0x11, 0x53, 0x54, 0x41, 0x54, 0x45, 0x5f, 0x55, 0x4e, 0x53, 0x50, 0x45, 0x43,
	0x49, 0x46, 0x49, 0x45, 0x44, 0x10, 0x00, 0x12, 0x0b, 0x0a, 0x07, 0x43, 0x52, 0x45, 0x41, 0x54,
	0x45, 0x44, 0x10, 0x01, 0x12, 0x0e, 0x0a, 0x0a, 0x49, 0x4e, 0x43, 0x4f, 0x4d, 0x50, 0x4c, 0x45,
	0x54, 0x45, 0x10, 0x02, 0x12, 0x0a, 0x0a, 0x06, 0x46, 0x41, 0x49, 0x4c, 0x45, 0x44, 0x10, 0x03,
	0x12, 0x0e, 0x0a, 0x0a, 0x55, 0x4e, 0x52, 0x45, 0x50, 0x4f, 0x52, 0x54, 0x45, 0x44, 0x10, 0x04,
	0x12, 0x12, 0x0a, 0x0e, 0x4e, 0x4f, 0x54, 0x5f, 0x41, 0x50, 0x50, 0x4c, 0x49, 0x43, 0x41, 0x42,
	0x4c, 0x45, 0x10, 0x05, 0x12, 0x0d, 0x0a, 0x09, 0x53, 0x55, 0x43, 0x43, 0x45, 0x45, 0x44, 0x45,
	0x44, 0x10, 0x06, 0x12, 0x14, 0x0a, 0x10, 0x43, 0x41, 0x4e, 0x43, 0x45, 0x4c, 0x5f, 0x52, 0x45,
	0x51, 0x55, 0x45, 0x53, 0x54, 0x45, 0x44, 0x10, 0x07, 0x12, 0x0d, 0x0a, 0x09, 0x43, 0x41, 0x4e,
	0x43, 0x45, 0x4c, 0x4c, 0x45, 0x44, 0x10, 0x08, 0x12, 0x11, 0x0a, 0x0d, 0x43, 0x41, 0x4e, 0x43,
	0x45, 0x4c, 0x5f, 0x46, 0x41, 0x49, 0x4c, 0x45, 0x44, 0x10, 0x09, 0x22, 0x4c, 0x0a, 0x0c, 0x46,
	0x69, 0x72, 0x6d, 0x77, 0x61, 0x72, 0x65, 0x54, 0x79, 0x70, 0x65, 0x12, 0x1d, 0x0a, 0x19, 0x46,
	0x49, 0x52, 0x4d, 0x57, 0x41, 0x52, 0x45, 0x5f, 0x54, 0x59, 0x50, 0x45, 0x5f, 0x55, 0x4e, 0x53,
	0x50, 0x45, 0x43, 0x49, 0x46, 0x49, 0x45, 0x44, 0x10, 0x00, 0x12, 0x0d, 0x0a, 0x09, 0x52, 0x45,
	0x41, 0x44, 0x5f, 0x4f, 0x4e, 0x4c, 0x59, 0x10, 0x01, 0x12, 0x0e, 0x0a, 0x0a, 0x52, 0x45, 0x41,
	0x44, 0x5f, 0x57, 0x52, 0x49, 0x54, 0x45, 0x10, 0x02, 0x3a, 0x61, 0xea, 0x41, 0x5e, 0x0a, 0x28,
	0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65, 0x6f, 0x73, 0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e, 0x67,
	0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x61, 0x70, 0x69, 0x73, 0x2e, 0x63, 0x6f, 0x6d, 0x2f, 0x54, 0x65,
	0x73, 0x74, 0x45, 0x66, 0x66, 0x6f, 0x72, 0x74, 0x12, 0x19, 0x74, 0x65, 0x73, 0x74, 0x45, 0x66,
	0x66, 0x6f, 0x72, 0x74, 0x73, 0x2f, 0x7b, 0x74, 0x65, 0x73, 0x74, 0x5f, 0x65, 0x66, 0x66, 0x6f,
	0x72, 0x74, 0x7d, 0x2a, 0x0b, 0x74, 0x65, 0x73, 0x74, 0x45, 0x66, 0x66, 0x6f, 0x72, 0x74, 0x73,
	0x32, 0x0a, 0x74, 0x65, 0x73, 0x74, 0x45, 0x66, 0x66, 0x6f, 0x72, 0x74, 0x42, 0x0d, 0x0a, 0x0b,
	0x74, 0x65, 0x73, 0x74, 0x5f, 0x74, 0x61, 0x72, 0x67, 0x65, 0x74, 0x42, 0x04, 0x0a, 0x02, 0x6f,
	0x73, 0x42, 0x7e, 0x0a, 0x22, 0x63, 0x6f, 0x6d, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e,
	0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65, 0x6f, 0x73, 0x2e, 0x6d, 0x6f, 0x62, 0x6c, 0x61, 0x62, 0x2e,
	0x76, 0x31, 0x62, 0x65, 0x74, 0x61, 0x31, 0x42, 0x0e, 0x52, 0x65, 0x73, 0x6f, 0x75, 0x72, 0x63,
	0x65, 0x73, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x48, 0x01, 0x50, 0x01, 0x5a, 0x44, 0x67, 0x6f, 0x6f,
	0x67, 0x6c, 0x65, 0x2e, 0x67, 0x6f, 0x6c, 0x61, 0x6e, 0x67, 0x2e, 0x6f, 0x72, 0x67, 0x2f, 0x67,
	0x65, 0x6e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2f, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x61, 0x70,
	0x69, 0x73, 0x2f, 0x63, 0x68, 0x72, 0x6f, 0x6d, 0x65, 0x6f, 0x73, 0x2f, 0x6d, 0x6f, 0x62, 0x6c,
	0x61, 0x62, 0x2f, 0x76, 0x31, 0x62, 0x65, 0x74, 0x61, 0x31, 0x3b, 0x6d, 0x6f, 0x62, 0x6c, 0x61,
	0x62, 0x62, 0x06, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x33,
}

var (
	file_google_chromeos_moblab_v1beta1_resources_proto_rawDescOnce sync.Once
	file_google_chromeos_moblab_v1beta1_resources_proto_rawDescData = file_google_chromeos_moblab_v1beta1_resources_proto_rawDesc
)

func file_google_chromeos_moblab_v1beta1_resources_proto_rawDescGZIP() []byte {
	file_google_chromeos_moblab_v1beta1_resources_proto_rawDescOnce.Do(func() {
		file_google_chromeos_moblab_v1beta1_resources_proto_rawDescData = protoimpl.X.CompressGZIP(file_google_chromeos_moblab_v1beta1_resources_proto_rawDescData)
	})
	return file_google_chromeos_moblab_v1beta1_resources_proto_rawDescData
}

var file_google_chromeos_moblab_v1beta1_resources_proto_enumTypes = make([]protoimpl.EnumInfo, 6)
var file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes = make([]protoimpl.MessageInfo, 18)
var file_google_chromeos_moblab_v1beta1_resources_proto_goTypes = []interface{}{
	(Build_BuildStatus)(0),                       // 0: google.chromeos.moblab.v1beta1.Build.BuildStatus
	(Build_BuildType)(0),                         // 1: google.chromeos.moblab.v1beta1.Build.BuildType
	(CloudBuild_State)(0),                        // 2: google.chromeos.moblab.v1beta1.CloudBuild.State
	(TestEffort_State)(0),                        // 3: google.chromeos.moblab.v1beta1.TestEffort.State
	(TestEffort_FirmwareType)(0),                 // 4: google.chromeos.moblab.v1beta1.TestEffort.FirmwareType
	(TestEffort_Pool_PoolType)(0),                // 5: google.chromeos.moblab.v1beta1.TestEffort.Pool.PoolType
	(*BuildTarget)(nil),                          // 6: google.chromeos.moblab.v1beta1.BuildTarget
	(*Model)(nil),                                // 7: google.chromeos.moblab.v1beta1.Model
	(*Milestone)(nil),                            // 8: google.chromeos.moblab.v1beta1.Milestone
	(*Build)(nil),                                // 9: google.chromeos.moblab.v1beta1.Build
	(*BuildArtifact)(nil),                        // 10: google.chromeos.moblab.v1beta1.BuildArtifact
	(*CloudBuild)(nil),                           // 11: google.chromeos.moblab.v1beta1.CloudBuild
	(*Session)(nil),                              // 12: google.chromeos.moblab.v1beta1.Session
	(*Timeout)(nil),                              // 13: google.chromeos.moblab.v1beta1.Timeout
	(*TradefedTest)(nil),                         // 14: google.chromeos.moblab.v1beta1.TradefedTest
	(*TestEffort)(nil),                           // 15: google.chromeos.moblab.v1beta1.TestEffort
	nil,                                          // 16: google.chromeos.moblab.v1beta1.Session.DimensionsEntry
	(*TestEffort_BoardModel)(nil),                // 17: google.chromeos.moblab.v1beta1.TestEffort.BoardModel
	(*TestEffort_Pool)(nil),                      // 18: google.chromeos.moblab.v1beta1.TestEffort.Pool
	(*TestEffort_AndroidBuildTarget)(nil),        // 19: google.chromeos.moblab.v1beta1.TestEffort.AndroidBuildTarget
	(*TestEffort_FirmwareTestEffortVersion)(nil), // 20: google.chromeos.moblab.v1beta1.TestEffort.FirmwareTestEffortVersion
	(*TestEffort_GscTestEffortVersion)(nil),      // 21: google.chromeos.moblab.v1beta1.TestEffort.GscTestEffortVersion
	(*TestEffort_FirmwareTarget)(nil),            // 22: google.chromeos.moblab.v1beta1.TestEffort.FirmwareTarget
	(*TestEffort_FirmwareConfig)(nil),            // 23: google.chromeos.moblab.v1beta1.TestEffort.FirmwareConfig
	(*timestamppb.Timestamp)(nil),                // 24: google.protobuf.Timestamp
	(*durationpb.Duration)(nil),                  // 25: google.protobuf.Duration
}
var file_google_chromeos_moblab_v1beta1_resources_proto_depIdxs = []int32{
	0,  // 0: google.chromeos.moblab.v1beta1.Build.status:type_name -> google.chromeos.moblab.v1beta1.Build.BuildStatus
	1,  // 1: google.chromeos.moblab.v1beta1.Build.type:type_name -> google.chromeos.moblab.v1beta1.Build.BuildType
	2,  // 2: google.chromeos.moblab.v1beta1.CloudBuild.status:type_name -> google.chromeos.moblab.v1beta1.CloudBuild.State
	24, // 3: google.chromeos.moblab.v1beta1.CloudBuild.create_time:type_name -> google.protobuf.Timestamp
	24, // 4: google.chromeos.moblab.v1beta1.CloudBuild.start_time:type_name -> google.protobuf.Timestamp
	24, // 5: google.chromeos.moblab.v1beta1.CloudBuild.finish_time:type_name -> google.protobuf.Timestamp
	16, // 6: google.chromeos.moblab.v1beta1.Session.dimensions:type_name -> google.chromeos.moblab.v1beta1.Session.DimensionsEntry
	13, // 7: google.chromeos.moblab.v1beta1.Session.timeout:type_name -> google.chromeos.moblab.v1beta1.Timeout
	14, // 8: google.chromeos.moblab.v1beta1.Session.tradefed_test:type_name -> google.chromeos.moblab.v1beta1.TradefedTest
	25, // 9: google.chromeos.moblab.v1beta1.Timeout.job_timeout:type_name -> google.protobuf.Duration
	25, // 10: google.chromeos.moblab.v1beta1.Timeout.test_timeout:type_name -> google.protobuf.Duration
	25, // 11: google.chromeos.moblab.v1beta1.Timeout.start_timeout:type_name -> google.protobuf.Duration
	17, // 12: google.chromeos.moblab.v1beta1.TestEffort.board_model:type_name -> google.chromeos.moblab.v1beta1.TestEffort.BoardModel
	18, // 13: google.chromeos.moblab.v1beta1.TestEffort.pools:type_name -> google.chromeos.moblab.v1beta1.TestEffort.Pool
	19, // 14: google.chromeos.moblab.v1beta1.TestEffort.android:type_name -> google.chromeos.moblab.v1beta1.TestEffort.AndroidBuildTarget
	3,  // 15: google.chromeos.moblab.v1beta1.TestEffort.state:type_name -> google.chromeos.moblab.v1beta1.TestEffort.State
	24, // 16: google.chromeos.moblab.v1beta1.TestEffort.create_time:type_name -> google.protobuf.Timestamp
	23, // 17: google.chromeos.moblab.v1beta1.TestEffort.firmware_configs:type_name -> google.chromeos.moblab.v1beta1.TestEffort.FirmwareConfig
	5,  // 18: google.chromeos.moblab.v1beta1.TestEffort.Pool.type:type_name -> google.chromeos.moblab.v1beta1.TestEffort.Pool.PoolType
	20, // 19: google.chromeos.moblab.v1beta1.TestEffort.FirmwareTarget.ec:type_name -> google.chromeos.moblab.v1beta1.TestEffort.FirmwareTestEffortVersion
	20, // 20: google.chromeos.moblab.v1beta1.TestEffort.FirmwareTarget.ap:type_name -> google.chromeos.moblab.v1beta1.TestEffort.FirmwareTestEffortVersion
	21, // 21: google.chromeos.moblab.v1beta1.TestEffort.FirmwareTarget.gsc:type_name -> google.chromeos.moblab.v1beta1.TestEffort.GscTestEffortVersion
	20, // 22: google.chromeos.moblab.v1beta1.TestEffort.FirmwareTarget.fpmcu:type_name -> google.chromeos.moblab.v1beta1.TestEffort.FirmwareTestEffortVersion
	22, // 23: google.chromeos.moblab.v1beta1.TestEffort.FirmwareConfig.firmware_target:type_name -> google.chromeos.moblab.v1beta1.TestEffort.FirmwareTarget
	4,  // 24: google.chromeos.moblab.v1beta1.TestEffort.FirmwareConfig.firmware_types:type_name -> google.chromeos.moblab.v1beta1.TestEffort.FirmwareType
	25, // [25:25] is the sub-list for method output_type
	25, // [25:25] is the sub-list for method input_type
	25, // [25:25] is the sub-list for extension type_name
	25, // [25:25] is the sub-list for extension extendee
	0,  // [0:25] is the sub-list for field type_name
}

func init() { file_google_chromeos_moblab_v1beta1_resources_proto_init() }
func file_google_chromeos_moblab_v1beta1_resources_proto_init() {
	if File_google_chromeos_moblab_v1beta1_resources_proto != nil {
		return
	}
	if !protoimpl.UnsafeEnabled {
		file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*BuildTarget); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[1].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*Model); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[2].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*Milestone); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[3].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*Build); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[4].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*BuildArtifact); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[5].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*CloudBuild); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[6].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*Session); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[7].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*Timeout); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[8].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*TradefedTest); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[9].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*TestEffort); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[11].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*TestEffort_BoardModel); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[12].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*TestEffort_Pool); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[13].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*TestEffort_AndroidBuildTarget); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[14].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*TestEffort_FirmwareTestEffortVersion); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[15].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*TestEffort_GscTestEffortVersion); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[16].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*TestEffort_FirmwareTarget); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[17].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*TestEffort_FirmwareConfig); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[6].OneofWrappers = []interface{}{
		(*Session_TradefedTest)(nil),
	}
	file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[9].OneofWrappers = []interface{}{
		(*TestEffort_BoardModel_)(nil),
		(*TestEffort_Android)(nil),
	}
	file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes[16].OneofWrappers = []interface{}{
		(*TestEffort_FirmwareTarget_Ec)(nil),
		(*TestEffort_FirmwareTarget_Ap)(nil),
		(*TestEffort_FirmwareTarget_Gsc)(nil),
		(*TestEffort_FirmwareTarget_Fpmcu)(nil),
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_google_chromeos_moblab_v1beta1_resources_proto_rawDesc,
			NumEnums:      6,
			NumMessages:   18,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_google_chromeos_moblab_v1beta1_resources_proto_goTypes,
		DependencyIndexes: file_google_chromeos_moblab_v1beta1_resources_proto_depIdxs,
		EnumInfos:         file_google_chromeos_moblab_v1beta1_resources_proto_enumTypes,
		MessageInfos:      file_google_chromeos_moblab_v1beta1_resources_proto_msgTypes,
	}.Build()
	File_google_chromeos_moblab_v1beta1_resources_proto = out.File
	file_google_chromeos_moblab_v1beta1_resources_proto_rawDesc = nil
	file_google_chromeos_moblab_v1beta1_resources_proto_goTypes = nil
	file_google_chromeos_moblab_v1beta1_resources_proto_depIdxs = nil
}
